@@ -156,7 +156,7 @@ public class GuardBadStorageImpl implements GuardBadStorage {
         GuardConfigurationService configService = Services.getService(GuardConfigurationService.class);
         Bad badEntry = getBad(id);
         if (badEntry != null) {
-            long differential = configService.getIntProperty(GuardProperty.badMinuteLock) * 60 * 1000;
+            long differential = configService.getIntProperty(GuardProperty.badMinuteLock) * 60L * 1000;
             if (badEntry.getLast().getTime() > (badEntry.getCurrentTime().getTime() - differential)) {
                 if (badEntry.getCount() > threshold) {
                     return true;
