@@ -122,6 +122,9 @@ public class AutoCryptServiceImpl implements AutoCryptService {
      * @return
      */
     private String createHeader (String keyData, String fromAddr, boolean mutual) {
+        if (keyData == null || keyData.isEmpty()) {
+            return null;
+        }
         StringBuilder sb = new StringBuilder();
         sb.append("addr=");
         sb.append(fromAddr);
@@ -153,19 +156,40 @@ public class AutoCryptServiceImpl implements AutoCryptService {
             key = keyService.getKeys(userId, cid);
         }
 
-        if (key != null && key.getPGPPublicKeyRing() != null) {
+        if (key != null && key.getPGPPublicKeyRing() != null && key.getContextid() > 0) {  // Key exists and not guest
             if (key.getContextid() == cid && key.getUserid() == userId) {  // Verify match with userId, cid if retrieved by email
-                responseData =
-                    createHeader(
-                        AutoCryptUtils.createEncodedKeyString(key.getPGPPublicKeyRing(), emailAddress),
-                        key.getEmail(),
-                        configService.getBooleanProperty(GuardProperty.autoCryptMutual, userId, cid)  // If header should be set to mutual
-                        );
+                responseData = getHeaderValue(key, emailAddress);
             }
         }
         return responseData;
     }
 
+    private String getHeaderValue (GuardKeys key, String emailAddress) throws OXException {
+        return createHeader(
+            AutoCryptUtils.createEncodedKeyString(key.getPGPPublicKeyRing(), emailAddress == null ? key.getEmail() : emailAddress),
+            key.getEmail(),
+            configService.getBooleanProperty(GuardProperty.autoCryptMutual, key.getUserid(), key.getContextid())  // If header should be set to mutual
+            );
+    }
+
+    @Override
+    public void addOutgoingHeader(MimeMessage msg, GuardKeys key) throws OXException {
+        if (!configService.getBooleanProperty(GuardProperty.autoCryptEnabled, key.getUserid(), key.getContextid())) {
+            return;
+        }
+
+        String value = getHeaderValue(key, null);
+        if (value == null || value.isEmpty()) {
+            return;
+        }
+        try {
+            msg.addHeader("Autocrypt", value);
+            msg.saveChanges();
+        } catch (MessagingException e) {
+            LOG.error("Error adding autocrypt message", e);
+        }
+    }
+
     /* (non-Javadoc)
      * @see com.openexchange.guard.autocrypt.AutoCryptService#importKey(int, int, java.lang.String, java.lang.String, boolean)
      */
@@ -182,8 +206,11 @@ public class AutoCryptServiceImpl implements AutoCryptService {
         if (!AutoCryptUtils.confirmEmail(key)) {
             return new AutoCryptKeysResponse("Address mismatch");
         }
-        if (keyService.getKeys(key.getEmail()) != null) {
-            return new AutoCryptKeysResponse("Existing Guard Key");
+        GuardKeys gKey = keyService.getKeys(key.getEmail());
+        if (gKey != null) {
+            if (gKey.getContextid() > 0) {
+                return new AutoCryptKeysResponse("Existing Guard Key");
+            }
         }
         boolean newKey = false;
         boolean added = false;
