@@ -137,9 +137,11 @@ public interface GuardCipherService {
     /**
      * Generates and returns a random password. The length of the password is defines in the {@link GuardProperty}
      * 
+     * @param userId  Id of the user
+     * @param cid  The context of the user
      * @return The random password
      * @throws OXException if the password cannot be generated
      */
-    String generateRandomPassword() throws OXException;
+    String generateRandomPassword(int userId, int cid) throws OXException;
 
 }
