@@ -57,7 +57,6 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.InputStreamReader;
 import java.io.OutputStreamWriter;
-import java.io.PrintStream;
 import java.io.Writer;
 import java.nio.charset.StandardCharsets;
 import java.rmi.RemoteException;
@@ -97,7 +96,7 @@ public class Guard extends AbstractRmiCLI<Void> {
 
     private static final String DEFAULT_CONF_FOLDER = "/opt/open-xchange/etc";
 
-    private final boolean requiresAuth;
+    private final Boolean requiresAuth;
 
     /**
      * @param args
@@ -124,13 +123,13 @@ public class Guard extends AbstractRmiCLI<Void> {
     private boolean needsAuth(String[] args) {
         for (String arg : args) {
             if (arg.trim().equals("-D") || arg.trim().equals("--delete")) {
-                return true;
+                return Boolean.TRUE;
             }
             if (arg.trim().equals("-m") || arg.trim().equals("--import")) {
-                return true;
+                return Boolean.TRUE;
             }
         }
-        return false;
+        return Boolean.FALSE;
     }
 
     /*
@@ -240,7 +239,7 @@ public class Guard extends AbstractRmiCLI<Void> {
                 delete(createProxy(jmxHost, jmxPort, jmxUser, jmxPassword), email);
             } else if (cmd.hasOption('m')) {
                 String file = cmd.getOptionValue('m');
-                importPublic (createProxy(jmxHost, jmxPort, jmxUser, jmxPassword), file);
+                importPublic(createProxy(jmxHost, jmxPort, jmxUser, jmxPassword), file);
             } else if (cmd.hasOption('r')) {
                 String dry = cmd.getOptionValue('r');
                 if (dry != null && dry.toLowerCase().startsWith("update")) {
@@ -296,7 +295,7 @@ public class Guard extends AbstractRmiCLI<Void> {
         System.out.println(String.format("Guest (%s) has been reset.", email));
     }
 
-    private void importPublic (GuardMaintenanceMBean proxy, String filename) throws MBeanException {
+    private void importPublic(GuardMaintenanceMBean proxy, String filename) throws MBeanException {
         proxy.importPublic(filename);
         System.out.println("PGP Key Imported");
     }
@@ -309,7 +308,7 @@ public class Guard extends AbstractRmiCLI<Void> {
         System.out.println("Name: " + testResult.getDisplayName());
     }
 
-    private void repairDatabase (GuardMaintenanceMBean proxy, boolean dryRun) throws MBeanException {
+    private void repairDatabase(GuardMaintenanceMBean proxy, boolean dryRun) throws MBeanException {
         StringBuilder results = proxy.repair(dryRun);
         System.out.println(results);
         System.out.println("Repair procedure complete");
@@ -355,7 +354,7 @@ public class Guard extends AbstractRmiCLI<Void> {
      * @see com.openexchange.cli.AbstractCLI#requiresAdministrativePermission()
      */
     @Override
-    protected boolean requiresAdministrativePermission() {
+    protected Boolean requiresAdministrativePermission() {
         return requiresAuth;
     }
 
