@@ -14,18 +14,18 @@ public class ListUtil {
      * @return a separated string of items
      */
     public static <T> String  listToString(List<T> list, String separator) {
-        String ret = "";
+        StringBuilder sb = new StringBuilder();
         for(int i=0; i<list.size();i++) {
 
             //add the key id
-            ret += list.get(i);
+            sb.append(list.get(i));
 
             //add whitespace if not last key id
             if(i < list.size() - 1) {
-                ret += separator;
+                sb.append(separator);
             }
         }
-        return ret;
+        return sb.toString();
     }
 
     /**
@@ -37,13 +37,13 @@ public class ListUtil {
      * @return
      */
     public static <T> String listToDbValuesList(int count) {
-        String ret = "";
+        StringBuilder sb = new StringBuilder();
         for(int i=0; i<count;i++) {
-            ret += "?";
+            sb.append("?");
             if(i < count-1) {
-                ret += ",";
+                sb.append(",");
             }
         }
-        return ret;
+        return sb.toString();
     }
 }
