@@ -274,7 +274,7 @@ public class GuardConfigurationServiceImpl implements GuardConfigurationService
      */
     private <T> T getUserProperty(String property, int userId, int contextId, Class<T> coerceTo, T defaultValue) {
         if (contextId == 0) {
-            return defaultValue;
+            return getServerProperty(property, coerceTo, defaultValue);
         }
         if (contextId < 0) {
             contextId = -contextId;
