@@ -60,10 +60,15 @@ import com.openexchange.guard.database.GuardDatabaseService;
 import com.openexchange.guard.database.GuardShardingService;
 import com.openexchange.guard.database.init.GuardCreateTableService;
 import com.openexchange.guard.database.internal.GuardDatabaseServiceImpl;
+import com.openexchange.guard.database.internal.GuardShardingIDManagement;
 import com.openexchange.guard.database.internal.Services;
 import com.openexchange.guard.database.update.GuardCreateTableTask;
+import com.openexchange.guard.database.update.shardUpdate.ShardUpdaterService;
+import com.openexchange.guard.database.update.shardUpdate.ShardUpdaterServiceImpl;
+import com.openexchange.guard.database.update.shardUpdate.updates.AutoIncrement;
 import com.openexchange.guard.updater.ChangeOGKeyTableSizes;
 import com.openexchange.guard.updater.ChangePGPPublicKeySize;
+import com.openexchange.guard.updater.ChangePasswordTimeStampUpdateTask;
 import com.openexchange.guard.updater.CreateMailvelopeTableTask;
 import com.openexchange.guard.updater.SetDBEngineUpdateTask;
 import com.openexchange.osgi.HousekeepingActivator;
@@ -100,15 +105,27 @@ public class GuardDatabaseActivator extends HousekeepingActivator {
 
         // Register update tasks for user schema
         registerService(UpdateTaskProviderService.class, new DefaultUpdateTaskProviderService(new GuardCreateTableTask(databaseService)));
-        registerService(UpdateTaskProviderService.class, new DefaultUpdateTaskProviderService(new ChangePGPPublicKeySize(), new CreateMailvelopeTableTask(databaseService), new ChangeOGKeyTableSizes(), new SetDBEngineUpdateTask()));
+        registerService(UpdateTaskProviderService.class, new DefaultUpdateTaskProviderService(new ChangePGPPublicKeySize(),
+            new CreateMailvelopeTableTask(databaseService),
+            new ChangeOGKeyTableSizes(),
+            new SetDBEngineUpdateTask(),
+            new ChangePasswordTimeStampUpdateTask()));
 
         GuardConfigurationService guardConfigService = getService(GuardConfigurationService.class);
         GuardDatabaseService guardDatabaseService = new GuardDatabaseServiceImpl(databaseService, guardConfigService, getService(AssignmentFactory.class));
 
-        track(DBMigrationExecutorService.class, new DBMigrationServiceTracker(context, guardDatabaseService, guardConfigService, getService(AssignmentFactory.class)));
+        // Shard updating
+        ShardUpdaterService shardUpdates = new ShardUpdaterServiceImpl(this, guardDatabaseService,
+            new AutoIncrement(new GuardShardingIDManagement(guardDatabaseService)));
+
+        track(DBMigrationExecutorService.class,
+            new DBMigrationServiceTracker(context,
+                guardDatabaseService,
+                guardConfigService,
+                shardUpdates,
+                getService(AssignmentFactory.class)));
         trackService(GuardDatabaseService.class);
         trackService(GuardShardingService.class);
-
         openTrackers();
     }
 
