@@ -63,7 +63,15 @@ public interface DNSService {
 
     String getUrl(String email) throws OXException;
 
-    List<SRVRecord> getSrvs(String serviceName, String email) throws OXException;
+    /**
+     * Tries to get a service record from the given email's domain
+     *
+     * @param serviceName The name of the service to fetch
+     * @param email An email address containing the domain to search
+     * @return A {@link DNSResult} the result of the search
+     * @throws OXException
+     */
+    DNSResult getSrvs(String serviceName, String email) throws OXException;
 
     /**
      * Find the next in the priority list of SRV records
