@@ -117,17 +117,22 @@ public class FlagTrustingDNSValidator implements DNSValidator {
     public ValidationResult isValid(Message answer) {
         boolean hasFlag = hasFlag(answer, Flags.AD);
         String name = "unknown domain";
-        Record[] answerSection = answer.getSectionArray(Section.ANSWER);
-        if (answerSection != null && answerSection.length > 0) {
-            name = answerSection[0].getName().toString();
+        Record question = answer.getQuestion();
+        if(question != null) {
+            name = question.getName().toString();
         }
         if (!hasFlag) {
+            Record[] answerSection = answer.getSectionArray(Section.ANSWER);
             if (validationMode == ValidationMode.WARN) {
-                logger.warn("The header of the obtained SRV DNS record for the domain \"{}\" does not contain the AD (Authenticated Data) Flag. Please consider to enable DNSSEC for the domain.", name);
+                if (answerSection != null && answerSection.length > 0) /*only log if the we have got a real answer to prevent log spam*/ {
+                    logger.warn("The header of the obtained SRV DNS record for the domain \"{}\" does not contain the AD (Authenticated Data) Flag. Please consider to enable DNSSEC for the domain.", name);
+                }
                 return null;
             }
             else if (validationMode == ValidationMode.FAIL) {
-                logger.error("The header of the obtained SRV DNS record for the domain \"{}\" does not contain the AD (Authenticated Data) Flag and is discarded.", name);
+                if (answerSection != null && answerSection.length > 0) /*only log if the we have got a real answer to prevent log spam*/ {
+                    logger.error("The header of the obtained SRV DNS record for the domain \"{}\" does not contain the AD (Authenticated Data) Flag and is discarded.", name);
+                }
                 return new ValidationResult(false);
             }
         }
