@@ -59,7 +59,6 @@ import com.openexchange.guard.encryption.EncryptedItemsStorage;
 import com.openexchange.guard.encryption.internal.EncryptedItemsStorageImpl;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.keymanagement.storage.KeyTableStorage;
-import com.openexchange.guard.keys.PGPKeyService;
 import com.openexchange.guard.storage.Storage;
 import com.openexchange.osgi.HousekeepingActivator;
 
@@ -78,8 +77,7 @@ public class GuardEncryptionActivator extends HousekeepingActivator {
     @Override
     protected Class<?>[] getNeededServices() {
         return new Class<?>[] { GuardConfigurationService.class, GuardDatabaseService.class, GuardShardingService.class, GuardCipherFactoryService.class,
-            GuardKeyService.class, PGPKeyService.class,
-            KeyTableStorage.class, Storage.class };
+            GuardKeyService.class, KeyTableStorage.class, Storage.class };
     }
 
     /*
