@@ -21,7 +21,7 @@ import com.openexchange.guard.notification.GuardNotificationService;
 public class GuestResetServiceImpl implements GuestResetService {
 
     @Override
-    public void reset(String email, int templId, String host, boolean force, String ip) throws OXException {
+    public void reset(String email, String host, boolean force, String ip) throws OXException {
 
         GuardKeyService keyService = Services.getService(GuardKeyService.class);
         MailCreatorService mailCreatorService = Services.getService(MailCreatorService.class);
@@ -46,6 +46,8 @@ public class GuestResetServiceImpl implements GuestResetService {
             throw GuardGuestResetExceptionCodes.RECOVERY_EXISTS.create(email);
         }
 
+        int templId = guardConfigService.getIntProperty(GuardProperty.templateID, keys.getContextid() > 0 ? keys.getUserid() : -1, keys.getContextid());
+
         // Store resetId here
         TemporaryTokenService tokenService = new TemporaryTokenServiceImpl();
         Token token = new Token (email, keys.getUserid(), keys.getContextid());
@@ -59,7 +61,7 @@ public class GuestResetServiceImpl implements GuestResetService {
             url = "https://" + guardConfigService.getProperty(GuardProperty.externalReaderPath);
         }
         emailJson = mailCreatorService.addURL(emailJson, url + "?resetid=" + token.getToken() + "&user=" + email + "&lang=" + keys.getLanguage());
-        notifier.send(emailJson, keys.getLanguage());
+        notifier.send(emailJson, -1, keys.getContextid(), keys.getLanguage());
 
     }
 
