@@ -13,9 +13,11 @@ public interface GuestUpgradeService {
     /**
      * Upgrades a  guest user to an OX Guard user
      * @param email The email of the guest user
+     * @param userid The id of the new OX user
+     * @param cid The context of the new OX user
      * @throws OXException
      */
-    public void upgrade(String email) throws OXException;
+    public void upgrade(String email, String userid, String cid) throws OXException;
 
     /**
      * Upgrades a guest user to an OX Guard user
