@@ -56,7 +56,6 @@ import com.openexchange.guard.hkp.osgi.Services;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.keymanagement.commons.export.KeyExportUtil;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
-import com.openexchange.guard.keys.PGPKeyService;
 import com.openexchange.guard.ratifier.GuardRatifierService;
 
 /**
@@ -76,9 +75,8 @@ public class HKPGet {
      * @throws OXException
      */
     public String get(String search) throws OXException {
-
         if (search != null && !search.isEmpty()) {
-            PGPKeyService pgpKeyService = Services.getService(PGPKeyService.class);
+            HKPSearch hkpSearch = new HKPSearch();
             if (search.contains("@")) {  // If email search
 
                 String email = search.trim();
@@ -97,9 +95,9 @@ public class HKPGet {
                 PGPPublicKeyRing resultKeyRing = null;
                 if (search.length() > 8) {
                     Long req_id = LongUtil.stringToLong(search);
-                    resultKeyRing = pgpKeyService.getPublicKeyRingById(req_id, 0, 0);
+                    resultKeyRing = hkpSearch.getPublicKeyRingById(req_id, 0, 0);
                 } else {
-                    resultKeyRing = pgpKeyService.getPublicKeyRingById(normalizeSearch(search), 0, 0);
+                    resultKeyRing = hkpSearch.getPublicKeyRingById(normalizeSearch(search), 0, 0);
                 }
 
                 if (resultKeyRing != null) {
