@@ -18,6 +18,7 @@ import com.openexchange.guard.hkpclient.client.HKPClient.TLSMODE;
 import com.openexchange.guard.hkpclient.osgi.Services;
 import com.openexchange.guard.hkpclient.util.TimeTracker;
 import com.openexchange.guard.inputvalidation.DomainNameValidator;
+import com.openexchange.server.ServiceLookup;
 
 /**
  *
@@ -34,6 +35,7 @@ public class SRVHKPClientService implements HKPClientService {
     private static final String HKP_SERVICE_NAME = "_hkp._tcp.";
     private final HKPClientService delegate;
     private final boolean forceTLS;
+    private final ServiceLookup services;
 
     private class QueryResult {
 
@@ -58,8 +60,8 @@ public class SRVHKPClientService implements HKPClientService {
      *
      * Initializes a new {@link SRVHKPClientService}.
      */
-    public SRVHKPClientService() {
-        this(null, false);
+    public SRVHKPClientService(ServiceLookup services) {
+        this(null, false, services);
     }
 
     /**
@@ -69,9 +71,10 @@ public class SRVHKPClientService implements HKPClientService {
      * @param delegate The service to delegate search queries to in a public key ring was not found
      * @param foceTLS True to only allow TLS connection to the HKP Server, false otherwise
      */
-    public SRVHKPClientService(HKPClientService delegate, boolean forceTLS) {
+    public SRVHKPClientService(HKPClientService delegate, boolean forceTLS, ServiceLookup services) {
         this.delegate = delegate;
         this.forceTLS = forceTLS;
+        this.services = services;
     }
 
     /**
@@ -111,7 +114,7 @@ public class SRVHKPClientService implements HKPClientService {
             }
             if (new DomainNameValidator().isValid(target) && !DomainNameValidator.isLocalAddress(target)) {  // Confirm target is a proper domain name
                 int port = nextcheck.getPort();
-                rings = new HKPClient(clientToken, isForceTLS(serviceName) ? TLSMODE.TLS : TLSMODE.BY_PORT).findKeys(target, port, email, timeout);
+                rings = new HKPClient(clientToken, isForceTLS(serviceName) ? TLSMODE.TLS : TLSMODE.BY_PORT, services).findKeys(target, port, email, timeout);
                 if (rings != null) {
                     return new QueryResult(rings, result.getValidationResult());
                 }
