@@ -103,7 +103,7 @@ public class RecipKey {
         setPubkey(key.getPublicKey());
         setNewGuestPass(null);
         setPgp(true);
-        setPGPPrivateKeyRing(key.getPGPPublicKeyRing());
+        setPGPPublicKeyRing(key.getPGPPublicKeyRing());
         setEmail(key.getEmail());
         setCid(key.getContextid());
         setExpired(PGPKeysUtil.checkAllExpired(key.getPGPPublicKeyRing()));
@@ -241,14 +241,13 @@ public class RecipKey {
         this.inline = inline;
     }
 
+    public void setPGPPublicKeyRing(PGPPublicKeyRing ring) {
+        this.pgpPublicKeyRing = ring;
+    }
     public PGPPublicKeyRing getPGPPublicKeyRing() {
         return pgpPublicKeyRing;
     }
 
-    public void setPGPPrivateKeyRing(PGPPublicKeyRing pgpring) {
-        this.pgpPublicKeyRing = pgpring;
-    }
-
     public PGPSecretKeyRing getPGPSecretKeyRing() {
         return pgpSecretKeyRing;
     }
@@ -265,6 +264,12 @@ public class RecipKey {
         return this.keySource;
     }
 
+    /**
+     * Returns if Guard treats this key as "new" and _will_ create new key material for this recipient during next encryption.
+     *
+     * @return True, if guard treats this key as new and will create new key material, False otherwise
+     * @see {@link RecipKey#isNewCreated} to determine if guard already created new key material.
+     */
     public boolean isNewKey() {
         if ((this.pgpPublicKeyRing == null) && (this.newGuestPass == null) && (this.pubkey == null)) {
             return true;
@@ -272,10 +277,20 @@ public class RecipKey {
         return false;
     }
 
+    /**
+     * Returns true if Guard created new key material.
+     *
+     * @return True, if guard created a new key, false otherwise
+     * @see {@link RecipKey#isNewKey()} to determine if guard will create new key material for this recipient
+     */
     public boolean isNewCreated() {
         return isNewCreated;
     }
 
+    /**
+     * Flags that Guard created new Key material
+     *
+     */
     public void setNewCreated() {
         this.isNewCreated = true;
     }
