@@ -112,7 +112,7 @@ public class KeyRecoveryServiceImpl implements KeyRecoveryService {
      */
     @Override
     public boolean checkCreateRecovery(int contextId, int userId) throws OXException {
-        if (configurationService.getBooleanProperty(GuardProperty.noRecovery)) {
+        if (configurationService.getBooleanProperty(GuardProperty.noRecovery, userId, contextId)) {
             // If global no Recovery then return false.
             return false;
         }
