@@ -92,6 +92,8 @@ public class DefaultRecipKeyLookupStrategy implements RecipKeyLookupStrategy {
             new UserUploadedRecipKeyLookupStrategy(senderUserId, senderContextId),
             new GuardRecipKeyLookupStrategy(),
             new MailResolverRecipKeyLookupStrategy(),
+            new AutoCryptLookupStrategy(senderUserId, senderContextId),
+            new WKSRecipKeyLookupStrategy(),
             new HKPRecipKeyLookupStrategy(hkpClientToken),
             new GuestRecipKeyLookupStrategy(senderContextId),
         }).lookup(email, timeout);
@@ -100,7 +102,14 @@ public class DefaultRecipKeyLookupStrategy implements RecipKeyLookupStrategy {
             logger.info("Could not find a recipient for email {}", email);
         }
         else {
-            logger.info("Found a recipient for email {}", email);
+            if(recipKey.isNewKey()) {
+                logger.info("Guard will create a new {} for email {}",
+                    recipKey.isGuest() ? "guest key" : "key" ,
+                    email);
+            }
+            else {
+                logger.info("Found a recipient for email {}", email);
+            }
         }
         return recipKey;
     }
