@@ -54,7 +54,7 @@ import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.keymanagement.commons.RecipKey;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.keymanagement.services.impl.osgi.Services;
-import com.openexchange.guard.keymanagement.services.lookup.RecipKeyLookupStrategy;
+import com.openexchange.guard.keymanagement.services.lookup.AbstractRecipKeyLookupStrategy;
 import com.openexchange.guard.oxapi.capabilities.Capabilities;
 import com.openexchange.guard.user.OXUser;
 import com.openexchange.guard.user.OXUserService;
@@ -68,7 +68,7 @@ import com.openexchange.guard.user.OXUserService;
  * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
  * @since v2.6.0
  */
-public class MailResolverRecipKeyLookupStrategy implements RecipKeyLookupStrategy {
+public class MailResolverRecipKeyLookupStrategy extends AbstractRecipKeyLookupStrategy {
 
     /**
      * Internal method to convert a {@link OXUser} object into a {@link RecipKey} object
@@ -98,7 +98,7 @@ public class MailResolverRecipKeyLookupStrategy implements RecipKeyLookupStrateg
         if (user != null && !user.isGuest() /* don't handle guest here; use the guest lookup strategy */) {
             //First, let's check if this is an alias for a known user
             GuardKeys aliasKeys = Services.getService(GuardKeyService.class).getKeys(user.getId(), user.getContextId());
-            if (aliasKeys != null) {
+            if (aliasKeys != null && hasValidEncryptionKey(aliasKeys)) {
                 return new RecipKey(aliasKeys);
             } else {
                 //Check if the resolved OX user has mail and guard capabilities enabled
