@@ -57,6 +57,7 @@ import org.bouncycastle.openpgp.PGPEncryptedData;
 import org.osgi.framework.BundleContext;
 import com.openexchange.contact.ContactService;
 import com.openexchange.guard.antiabuse.GuardAntiAbuseService;
+import com.openexchange.guard.autocrypt.AutoCryptService;
 import com.openexchange.guard.cipher.GuardCipherAlgorithm;
 import com.openexchange.guard.cipher.GuardCipherFactoryService;
 import com.openexchange.guard.cipher.GuardCipherService;
@@ -100,6 +101,7 @@ import com.openexchange.guard.secondfactor.SecondFactorService;
 import com.openexchange.guard.session.GuardSessionService;
 import com.openexchange.guard.translation.GuardTranslationService;
 import com.openexchange.guard.user.OXUserService;
+import com.openexchange.guard.wksclient.WKSClientService;
 import com.openexchange.osgi.HousekeepingActivator;
 import com.openexchange.pgp.keys.parsing.PGPKeyRingParser;
 
@@ -121,7 +123,12 @@ public class KeyManagementServicesImplActivator extends HousekeepingActivator {
         return new Class<?>[] { GuardCipherFactoryService.class, GuardConfigurationService.class, GuardShardingService.class, GuardRatifierService.class,
                                 KeyTableStorage.class, EmailStorage.class, KeyCacheStorage.class, PGPKeysStorage.class, OGPGPKeysStorage.class,
                                 OXUserService.class, GuardAntiAbuseService.class, GuardSessionService.class, GuardTranslationService.class,
-                                HKPClientService.class, PGPKeyRingParser.class, ContactService.class, SecondFactorService.class};
+                                HKPClientService.class, WKSClientService.class, PGPKeyRingParser.class, ContactService.class, SecondFactorService.class};
+    }
+
+    @Override
+    protected Class<?>[] getOptionalServices() {
+        return new Class<?>[] { AutoCryptService.class };
     }
 
     private int getSymetricKeyAlgorithm() {
@@ -177,7 +184,6 @@ public class KeyManagementServicesImplActivator extends HousekeepingActivator {
         GuardKeyService keyService = new GuardKeyServiceImpl();
         registerService(GuardKeyService.class, keyService);
         trackService(GuardKeyService.class);
-        openTrackers();
 
         //register the key recovery service
         KeyRecoveryService keyRecoveryService = new KeyRecoveryServiceImpl(getService(GuardConfigurationService.class), getService(OXUserService.class));
@@ -192,7 +198,6 @@ public class KeyManagementServicesImplActivator extends HousekeepingActivator {
                                                                            getSymetricKeyAlgorithm());
         registerService(KeyCreationService.class, keyCreationService);
         trackService(KeyCreationService.class);
-        openTrackers();
 
         // Password change service
         PasswordChangeService passService = new PasswordChangeServiceImpl();
@@ -211,7 +216,6 @@ public class KeyManagementServicesImplActivator extends HousekeepingActivator {
         registerService(RecipKeyService.class, new RecipKeyServiceImpl(keyService,
             getService(GuardConfigurationService.class).getIntProperty(GuardProperty.remoteKeyLookupTimeout)));
         trackService(RecipKeyService.class);
-        openTrackers();
 
         //Service for external public key handling
         PublicExternalKeyService publicExternalKeyService = new PublicExternalKeyServiceImpl(getService(GuardRatifierService.class), getService(OGPGPKeysStorage.class));
@@ -233,6 +237,7 @@ public class KeyManagementServicesImplActivator extends HousekeepingActivator {
 
         //Account creation Service
         registerService(AccountCreationService.class, new AccountCreationServiceImpl());
+        openTrackers();
     }
 
     /* (non-Javadoc)
