@@ -63,9 +63,9 @@ import com.openexchange.guard.common.util.ListUtil;
 import com.openexchange.guard.common.util.LongUtil;
 import com.openexchange.guard.database.GuardDatabaseService;
 import com.openexchange.guard.database.utils.DBUtils;
+import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.keymanagement.commons.PGPKeys;
 import com.openexchange.guard.keymanagement.storage.PGPKeysStorage;
-import com.openexchange.guard.keymanagement.storage.exceptions.GuardPGPKeysStorageExceptionCodes;
 import com.openexchange.guard.keymanagement.storage.impl.osgi.Services;
 
 public class PGPKeysStorageImpl implements PGPKeysStorage {
@@ -91,7 +91,7 @@ public class PGPKeysStorageImpl implements PGPKeysStorage {
             }
             return ret;
         } catch (SQLException e) {
-            throw GuardPGPKeysStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(resultSet, stmt);
             guardDatabaseService.backReadOnlyForGuard(connection);
@@ -115,7 +115,7 @@ public class PGPKeysStorageImpl implements PGPKeysStorage {
             }
             return null;
         } catch (SQLException e) {
-            throw GuardPGPKeysStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(resultSet, stmt);
             guardDatabaseService.backReadOnlyForGuard(connection);
@@ -139,7 +139,7 @@ public class PGPKeysStorageImpl implements PGPKeysStorage {
             }
             return null;
         } catch (SQLException e) {
-            throw GuardPGPKeysStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(resultSet, stmt);
             guardDatabaseService.backReadOnlyForGuard(connection);
@@ -169,7 +169,7 @@ public class PGPKeysStorageImpl implements PGPKeysStorage {
             }
             return ret;
         } catch (SQLException e) {
-            throw GuardPGPKeysStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(resultSet, stmt);
             guardDatabaseService.backReadOnlyForGuard(connection);
@@ -194,7 +194,7 @@ public class PGPKeysStorageImpl implements PGPKeysStorage {
             }
             return null;
         } catch (SQLException e) {
-            throw GuardPGPKeysStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(resultSet, stmt);
             guardDatabaseService.backReadOnlyForGuard(connection);
@@ -221,7 +221,7 @@ public class PGPKeysStorageImpl implements PGPKeysStorage {
             stmt.setLong(2, keyId);
             stmt.executeUpdate();
         } catch (SQLException e) {
-            throw GuardPGPKeysStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
         }
@@ -245,7 +245,7 @@ public class PGPKeysStorageImpl implements PGPKeysStorage {
 
             stmt.executeUpdate();
         } catch (SQLException e) {
-            throw GuardPGPKeysStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
             guardDatabaseService.backWritableForGuard(connection);
@@ -264,7 +264,7 @@ public class PGPKeysStorageImpl implements PGPKeysStorage {
 
             stmt.executeUpdate();
         } catch (SQLException e) {
-            throw GuardPGPKeysStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
             guardDatabaseService.backWritableForGuard(connection);
@@ -282,7 +282,7 @@ public class PGPKeysStorageImpl implements PGPKeysStorage {
             stmt.setString(1, email);
             stmt.executeUpdate();
         } catch (SQLException e) {
-            throw GuardPGPKeysStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
             guardDatabaseService.backWritableForGuard(connection);
@@ -301,7 +301,7 @@ public class PGPKeysStorageImpl implements PGPKeysStorage {
             stmt.setLong(2, keyId);
             stmt.executeUpdate();
         } catch (SQLException e) {
-            throw GuardPGPKeysStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
             guardDatabaseService.backWritableForGuard(connection);
@@ -341,7 +341,7 @@ public class PGPKeysStorageImpl implements PGPKeysStorage {
             stmt.setInt(3, contextId);
             stmt.executeUpdate();
         } catch (SQLException e) {
-            throw GuardPGPKeysStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
             guardDatabaseService.backWritableForGuard(connection);
