@@ -102,4 +102,17 @@ public interface MailCreatorService {
 
     List<String> getFromAddress(String name, String email, int userid, int cid) throws OXException;
 
+    /**
+     * Creates Json Email from template
+     * @param templ
+     * @param to
+     * @param from
+     * @param host
+     * @param userid
+     * @param cid
+     * @return
+     * @throws OXException
+     */
+    JsonObject templToEmail(String templ, String to, List<String> from, String host, int userid, int cid) throws OXException;
+
 }
