@@ -64,8 +64,8 @@ import javax.mail.internet.MimeMultipart;
 import org.bouncycastle.openpgp.PGPPublicKey;
 import com.openexchange.guard.keymanagement.commons.RecipKey;
 import com.openexchange.guard.milter.service.MilterMail;
-import com.openexchange.guard.pgp.GuardPGPMimeMailCreator;
 import com.openexchange.pgp.core.PGPEncrypter;
+import com.openexchange.pgp.mail.tools.PGPMimeMailCreator;
 
 /**
  * {@link DoEncrypt}
@@ -129,8 +129,7 @@ public class DoEncrypt {
     }
 
     private MimeMessage createWrapper (byte[] data) throws Exception {
-        GuardPGPMimeMailCreator mailCreator = new GuardPGPMimeMailCreator();
-        MimeMultipart mp = mailCreator.createPGPMime(data, null);
+        MimeMultipart mp = new PGPMimeMailCreator().createPGPMimePart(new ByteArrayInputStream(data), null);
         MimeMessage new_message = new MimeMessage(Session.getDefaultInstance(new Properties()));
         new_message.setContent(mp);
         new_message.saveChanges();
