@@ -97,13 +97,13 @@ public class PGPMimeEncryptionService implements MimeEncryptionService {
     private final GuardConfigurationService configurationService;
     private final PGPMimeCryptoService pgpMimeCryptoService;
     private final HelpFileService helpFileService;
-    private GuardNotificationService guardNotificationService;
+    private final GuardNotificationService guardNotificationService;
     private final GuardGuestEMailMetadataService guardMetaDataService;
     private final EmailStorage emailStorage;
-    private GuardGuestService guestService;
-    private PGPSigningService pgpSigningService;
-    private MailCreatorService mailCreatorService;
-    private AutoCryptService autocryptService;
+    private final GuardGuestService guestService;
+    private final PGPSigningService pgpSigningService;
+    private final MailCreatorService mailCreatorService;
+    private final AutoCryptService autocryptService;
 
     private static Logger LOG = LoggerFactory.getLogger(PGPMimeEncryptionService.class);
 
@@ -182,6 +182,9 @@ public class PGPMimeEncryptionService implements MimeEncryptionService {
             throw MimeEncryptorExceptionCodes.SEND_UNABLE_FIND_KEYS.create("Unable to find singing keys");
         }
         SignMime signer = new SignMime(pgpMimeService, pgpSigningService);
+        // Add autocrypt header if applicable
+        autocryptService.addOutgoingHeader(msg.getMessage(), key);
+
         output.write(signer.signMime(msg, key, password).getBytes(StandardCharsets.UTF_8));
     }
 
