@@ -1,6 +1,7 @@
 package com.openexchange.guard.mime.encryptor.osgi;
 
 import org.slf4j.Logger;
+import com.openexchange.guard.autocrypt.AutoCryptService;
 import com.openexchange.guard.cipher.GuardCipherFactoryService;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.email.storage.ogEmail.EmailStorage;
@@ -38,7 +39,8 @@ public class MimeEncryptor extends HousekeepingActivator {
             GuardNotificationService.class, GuardMasterKeyService.class, GuardCipherFactoryService.class, GuardKeyService.class,
             OXUserService.class, EncryptedItemsStorage.class, RecipKeyService.class, PGPCryptoService.class, PGPSigningService.class, Storage.class,
             AccountCreationService.class, PGPMimeService.class, PGPMimeCryptoService.class, HelpFileService.class,
-            GuardGuestEMailMetadataService.class, EmailStorage.class, GuardGuestService.class, SecondFactorService.class, HtmlService.class };
+            GuardGuestEMailMetadataService.class, EmailStorage.class, GuardGuestService.class, SecondFactorService.class,
+            HtmlService.class, AutoCryptService.class };
     }
 
     /**
@@ -62,7 +64,8 @@ public class MimeEncryptor extends HousekeepingActivator {
             getService(GuardNotificationService.class),
             getService(GuardGuestEMailMetadataService.class),
             getService(EmailStorage.class),
-            getService(MailCreatorService.class)));
+            getService(MailCreatorService.class),
+            getService(AutoCryptService.class)));
         logger.info("MimeEncryptor registered.");
 
         openTrackers();
