@@ -63,6 +63,7 @@ import javax.mail.internet.MimeMessage;
 import org.bouncycastle.openpgp.PGPPublicKey;
 import org.bouncycastle.openpgp.PGPSecretKey;
 import org.json.JSONException;
+import org.slf4j.Logger;
 import com.google.gson.JsonObject;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.util.CipherUtil;
@@ -78,6 +79,7 @@ import com.openexchange.guard.mailcreator.MailCreatorService;
 import com.openexchange.guard.mime.encryptor.Encryptor;
 import com.openexchange.guard.mime.encryptor.exceptions.MimeEncryptorExceptionCodes;
 import com.openexchange.guard.mime.encryptor.osgi.Services;
+import com.openexchange.guard.mime.encryptor.pgp.impl.HTMLStripper;
 import com.openexchange.guard.mime.helpfiles.HelpFileService;
 import com.openexchange.guard.mime.services.GuardParsedMimeMessage;
 import com.openexchange.guard.notification.GuardNotificationService;
@@ -96,9 +98,10 @@ import com.openexchange.pgp.mail.PGPMimeService;
  */
 public class PGPGuestEncryptor extends Encryptor {
 
-    private PGPMimeService pgpMimeService;
-    private HelpFileService helpFileService;
-    private GuardGuestService guestService;
+    private final PGPMimeService pgpMimeService;
+    private final HelpFileService helpFileService;
+    private final GuardGuestService guestService;
+    private static Logger LOG = org.slf4j.LoggerFactory.getLogger(PGPGuestEncryptor.class);
 
     /**
      * Initializes a new {@link PGPGuestEncryptor}.
@@ -269,10 +272,13 @@ public class PGPGuestEncryptor extends Encryptor {
             id = "pgp-" + id;  // After storing, add the pgp identifier
 
             String guestMessage = recip.isNewCreated() ? msg.getGuestMessage() : "";  // Only attach Guest message for new users
+            if (guestMessage != null && !guestMessage.isEmpty()) {  // If GuestMessage is empty, remove all HTML tags as this should just be plaintext.
+                guestMessage = new HTMLStripper().convertTextHTML(guestMessage);
+            }
             JsonObject email = mailCreatorService.createBlankGuestMail(recip.getLang(), templId, messageId, host, userid, cid, guestMessage);
             if (email == null) {
-                // TODO THROW ERROR
-                return false;
+                LOG.error("Unable to create blank Guest mail template");
+                throw MimeEncryptorExceptionCodes.SEND_EMAIL_ERROR.create(recip.getEmail());
             }
             email = mailCreatorService.addTo(email, recip.getName(), recip.getEmail(), recip.getType());
             email = mailCreatorService.addFrom(email, msg.getFromAddress().getPersonal(), msg.getFromAddress().getAddress());
@@ -282,7 +288,12 @@ public class PGPGuestEncryptor extends Encryptor {
             }
             email = mailCreatorService.noSave(email);
 
-            email = mailCreatorService.addURL(email, createShareLink(msg.getSenderSessionId(), id, recip));
+            final String shareLink = createShareLink(msg.getSenderSessionId(), id, recip);
+            if (shareLink == null) {
+                LOG.error("Unable to create Guard guest share link");
+                throw MimeEncryptorExceptionCodes.SEND_EMAIL_ERROR.create(recip.getEmail());
+            }
+            email = mailCreatorService.addURL(email, shareLink);
 
             storeEmail(id, recip, encrypted);
 
