@@ -55,6 +55,7 @@ import java.util.List;
 import javax.mail.Message;
 import javax.mail.MessagingException;
 import javax.mail.internet.AddressException;
+import javax.mail.internet.InternetAddress;
 import javax.mail.internet.MimeMessage;
 import org.apache.commons.io.output.ByteArrayOutputStream;
 import org.apache.commons.lang3.ArrayUtils;
@@ -207,7 +208,9 @@ public class PGPProcessMime implements ProcessMime {
                 encryptor = new PGPInlineEncryptor(pgpCryptoService, msg, recips, userId, contextId, password);
             } else {
                 if (!msg.isDraft() && autocryptService != null) {  // For emails being sent, attach all gossip headers
-                    String autocryptHeader = autocryptService.getOutgoingHeaderString(userId, contextId, null);
+                    final InternetAddress addr = msg.getFromAddress();
+                    String autocryptHeader =
+                        autocryptService.getOutgoingHeaderString(userId, contextId, addr == null ? null : addr.getAddress());
                     if (autocryptHeader != null && !autocryptHeader.isEmpty()) {
                         msg.getMessage().addHeader("Autocrypt", autocryptHeader);
                     }
@@ -248,7 +251,7 @@ public class PGPProcessMime implements ProcessMime {
     private void send(Message message, String senderEmail, int userId, int senderCid, ArrayList<RecipKey> recipients, String remoteIp) throws OXException {
         String fromAddress = getFromEmailAddress(recipients, senderEmail);
         for(RecipKey recipient : recipients) {
-            this.guardNotificationService.sendMessage(message, fromAddress, userId, senderCid, recipient.getLang(), remoteIp);
+            this.guardNotificationService.sendMessage(message, recipient.getEmail(), fromAddress, userId, senderCid, recipient.getLang(), remoteIp);
         }
     }
 
