@@ -142,7 +142,7 @@ public class PGPInlineEncryptor extends Encryptor {
         public Object getData() {
             return this.data;
         }
-        
+
         public String getContentId() {
             return this.contentID;
         }
@@ -294,7 +294,7 @@ public class PGPInlineEncryptor extends Encryptor {
      * @throws JSONException
      */
     private String doEncrypt(String toEncrypt) throws OXException, IOException, PGPException, JSONException {
-        InputStream in = new ByteArrayInputStream(toEncrypt.getBytes());
+        InputStream in = new ByteArrayInputStream(toEncrypt.getBytes(StandardCharsets.UTF_8));
         ByteArrayOutputStream encrypted = new ByteArrayOutputStream();
         doEncrypt(in, encrypted);
         in.close();
