@@ -49,6 +49,7 @@
 
 package com.openexchange.guard.mime.services;
 
+import java.io.InputStream;
 import java.io.UnsupportedEncodingException;
 import javax.mail.Address;
 import javax.mail.Message.RecipientType;
@@ -68,26 +69,22 @@ import com.openexchange.exception.OXException;
  */
 public class GuardParsedMimeMessage {
 
-    private MimeMessage msg;
-    private JSONArray recipients;
-    private JSONObject settings;
+    private MimeMessage      msg;
+    private JSONArray        recipients;
+    private JSONObject       settings;
     private final MimeParser mime;
-    private final int senderUserId;
-    private final int senderContextId;
-    private String senderSessionId;
-    private final String fromName;
-    private final boolean draft;
-    private final String host;
-    private String senderEmail;
-    private boolean senderIsGuest;
-    private String senderIp;
+    private final int        senderUserId;
+    private final int        senderContextId;
+    private String           senderSessionId;
+    private final String     fromName;
+    private final boolean    draft;
+    private final String     host;
+    private final String     senderEmail;
+    private final boolean    senderIsGuest;
+    private String           senderIp;
 
-    public GuardParsedMimeMessage (String msg, String json, int userid, int cid, String fromName, String host, String senderEmail, boolean senderIsGuest) throws UnsupportedEncodingException, MessagingException, JSONException {
-        this (msg, json, userid, cid, fromName, false, host, senderEmail, senderIsGuest);
-    }
-
-    public GuardParsedMimeMessage (String msg, JSONObject json, int userid, int cid, String fromName, boolean draft, String host, String senderEmail, boolean senderIsGuest) throws UnsupportedEncodingException, MessagingException, JSONException {
-        this.mime = new MimeParser(msg.getBytes("UTF-8"));
+    public GuardParsedMimeMessage(InputStream msg, JSONObject json, int userid, int cid, String fromName, boolean draft, String host, String senderEmail, boolean senderIsGuest) throws UnsupportedEncodingException, MessagingException, JSONException {
+        this.mime = new MimeParser(msg);
         this.msg = this.mime.getMessage();
         if (json != null) {
             if (json.has("security")) {
@@ -100,7 +97,7 @@ public class GuardParsedMimeMessage {
             } else {
                 this.recipients = new JSONArray();
             }
-            if(json.has("senderSessionId")) {
+            if (json.has("senderSessionId")) {
                 this.senderSessionId = json.getString("senderSessionId");
             }
             if (json.has("senderIp")) {
@@ -118,10 +115,6 @@ public class GuardParsedMimeMessage {
         this.senderIsGuest = senderIsGuest;
     }
 
-    public GuardParsedMimeMessage (String msg, String json, int userid, int cid, String fromName, boolean draft, String host, String senderEmail, boolean senderIsGuest) throws UnsupportedEncodingException, MessagingException, JSONException {
-        this(msg, json != null ? new JSONObject(json) : null, userid, cid, fromName, draft, host, senderEmail, senderIsGuest);
-    }
-
     public void setMessage(MimeMessage msg) {
         this.msg = msg;
     }
@@ -130,11 +123,11 @@ public class GuardParsedMimeMessage {
         return msg;
     }
 
-    public MimeParser getParser () {
+    public MimeParser getParser() {
         return mime;
     }
 
-    public JSONArray getRecipients () {
+    public JSONArray getRecipients() {
         return recipients;
     }
 
@@ -161,6 +154,7 @@ public class GuardParsedMimeMessage {
 
     /**
      * Pulls Guest greeting message from sent JSON
+     *
      * @return
      */
     public String getGuestMessage() {
@@ -176,6 +170,7 @@ public class GuardParsedMimeMessage {
 
     /**
      * Pulls selected Guest language from JSON
+     *
      * @return
      * @throws JSONException
      */
@@ -188,6 +183,7 @@ public class GuardParsedMimeMessage {
 
     /**
      * Pull guest pin from JSON
+     *
      * @return
      * @throws JSONException
      */
@@ -202,7 +198,7 @@ public class GuardParsedMimeMessage {
         return this.senderUserId;
     }
 
-    public int getSenderContextId () {
+    public int getSenderContextId() {
         return this.senderContextId;
     }
 
@@ -212,9 +208,10 @@ public class GuardParsedMimeMessage {
 
     /**
      * Parse the from address from message header
+     *
      * @return
      */
-    public InternetAddress getFromAddress () {
+    public InternetAddress getFromAddress() {
         try {
             Address[] from = this.msg.getFrom();
             if (from.length > 0) {
@@ -238,9 +235,10 @@ public class GuardParsedMimeMessage {
 
     /**
      * Parse the subject from message header
+     *
      * @return
      */
-    public String getSubject () {
+    public String getSubject() {
         try {
             return this.msg.getHeader("Subject", null);
         } catch (MessagingException e) {
@@ -250,30 +248,33 @@ public class GuardParsedMimeMessage {
 
     /**
      * Returns if message is a draft message
+     *
      * @return
      */
-    public boolean isDraft () {
+    public boolean isDraft() {
         return draft;
     }
 
     /**
      * Returns the domain that the client was using
+     *
      * @return
      */
-    public String getHost () {
+    public String getHost() {
         return host;
     }
 
     /**
      * TO find the type of recipient, parse the mime header for the email address
      * If not in Mime, then returns bcc
+     *
      * @param email
      * @return
      */
-    public RecipientType getRecipType (String email) {
+    public RecipientType getRecipType(String email) {
         try {
-            String [] toHeaders = this.msg.getHeader("To");
-            if(toHeaders != null) {
+            String[] toHeaders = this.msg.getHeader("To");
+            if (toHeaders != null) {
                 for (String to : toHeaders) {
                     if (to.toLowerCase().contains(email.toLowerCase())) {
                         return RecipientType.TO;
@@ -281,8 +282,8 @@ public class GuardParsedMimeMessage {
                 }
             }
 
-            String [] ccHeaders = this.msg.getHeader("Cc");
-            if(ccHeaders != null) {
+            String[] ccHeaders = this.msg.getHeader("Cc");
+            if (ccHeaders != null) {
                 for (String cc : ccHeaders) {
                     if (cc.toLowerCase().contains(email.toLowerCase())) {
                         return RecipientType.CC;
@@ -291,7 +292,7 @@ public class GuardParsedMimeMessage {
             }
 
             String[] bcHeaders = this.msg.getHeader("Bc");
-            if(bcHeaders != null) {
+            if (bcHeaders != null) {
                 for (String bc : bcHeaders) {
                     if (bc.toLowerCase().contains(email.toLowerCase())) {
                         return RecipientType.BCC;
@@ -315,21 +316,16 @@ public class GuardParsedMimeMessage {
 
     /**
      * Parse the headers for the message reference of original Guest email
+     *
      * @return
      * @throws OXException
+     * @throws JSONException
      */
-    public String getGuardMessagRef () throws OXException {
-        String[] refs;
-        try {
-            refs = msg.getHeader("X-Guard-msg-ref");
-            if (refs != null && refs.length > 0) {
-                return refs[0];
-            }
-        } catch (MessagingException e) {
-            throw OXException.general("Problem parsing msg header for Guard reference", e);
-        }
-        return null;
+    public String getGuardMessagRef() throws OXException, JSONException {
+        String refs = (this.settings.has("msgRef") ? this.settings.getString("msgRef") : null);
+        return refs;
     }
+
     /**
      * Gets the guest status of the sender
      *
