@@ -82,9 +82,13 @@ public interface GuardNotificationService {
      * Sends Mail message using SMTP Server
      *
      * @param msg The message
+     * @param toAddr the destination address. If null, then addresses from msg used
      * @param sender The sender address
+     * @param senderuserId the ID of the sender
+     * @param contextId the context ID of the sender
      * @param lang The language
+     * @param senderIp IP address of the sender
      * @throws OXException if an error occurred and the mail couldn't get send
      */
-    void sendMessage(Message msg, String sender, int senderUserId, int senderCid, String lang, String senderIp) throws OXException;
+    void sendMessage(Message msg, String toAddr, String sender, int senderUserId, int senderCid, String lang, String senderIp) throws OXException;
 }
