@@ -323,7 +323,7 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
     }
 
     @Override
-    public void sendMessage(final Message msg, final String sender, int senderUserId, int senderCid, final String lang, final String senderIp) throws OXException {
+    public void sendMessage(final Message msg, final String toAddr, final String sender, int senderUserId, int senderCid, final String lang, final String senderIp) throws OXException {
         final Session session = getSession(senderUserId, senderCid, isLocal(senderCid));
         Transport transport;
         try {
@@ -339,7 +339,7 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
             addOrigIp(msg, senderIp);
             transport = session.getTransport("smtp");
             transport.connect();
-            transport.sendMessage(msg, msg.getAllRecipients());
+            transport.sendMessage(msg, toAddr == null ? msg.getAllRecipients() : InternetAddress.parse(toAddr));
             transport.close();
         } catch (final MessagingException | UnsupportedEncodingException e) {
             LOG.error("Error sending email", e);
