@@ -85,7 +85,7 @@ public class Normalizer extends AbstractOXCalls {
 
     /**
      * Send string to backend for normalization. Primarily for PGP Inline
-     * 
+     *
      * @param data
      * @return
      * @throws Exception
@@ -105,14 +105,13 @@ public class Normalizer extends AbstractOXCalls {
 
     /**
      * Send email JSON to OX backend for normalization (strip scripts, etc)
-     * 
+     *
      * @param json
      * @return
      */
     public JsonObject normalize(JsonObject json) {
         if (json.has("attachments")) {
             JsonArray attachments = json.get("attachments").getAsJsonArray();
-            JsonArray newattach = new JsonArray();
             for (int i = 0; i < attachments.size(); i++) {
                 JsonObject attach = attachments.get(i).getAsJsonObject();
                 if (attach.has("content")) {
@@ -129,7 +128,6 @@ public class Normalizer extends AbstractOXCalls {
                             LOG.error("Error normalizing data", ex);
                         }
                     }
-                    newattach.add(attach);
                 }
             }
         }
