@@ -210,7 +210,7 @@ public class DBKeyRetrievalStrategy implements PGPKeyRetrievalStrategy {
                 logger.debug("Unable to extract PGPPublicKey with key id %s from PGPPublicKeyRing.", Long.toString(keyId));
             }
         }
-        logger.debug("Unable to find PGPPublicKey for keyId %s.", Long.toString(keyId));
+        logger.debug("Unable to find PGPPublicKey for keyId {}", Long.toString(keyId));
         return null;
     }
 }
