@@ -175,36 +175,6 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
         return (sb.toString());
     }
 
-    private static String getBoundry(final MimeMessage msg) throws MessagingException {
-        final String[] content = msg.getHeader("Content-Type");
-        if (content != null && content.length > 0) {
-            final int i = content[0].indexOf("boundary");
-            if (i > 0) {
-                String bndry = content[0].substring(i);
-                if (bndry.contains(";")) {
-                    bndry = bndry.substring(0, bndry.indexOf(";"));
-                }
-                return (bndry.substring(bndry.indexOf("\"")).replace("\"", ""));
-            }
-        }
-        return (null);
-    }
-
-    private static String getMimeSection(final String mime, String border) {
-        if (border == null) {
-            return (mime);
-        }
-        border = "--" + border;
-        final int j = mime.indexOf(border);
-        final int k = mime.indexOf(border, j + 10);
-        if (j > 0 && k > 0) {
-            final String data = mime.substring(j + 2 + border.length(), k - 2);
-            return (data);
-        }
-
-        return (mime);
-    }
-
     private String getDecoded(InputStream stream) throws MessagingException, IOException {
         ByteArrayOutputStream out = new ByteArrayOutputStream();
         IOUtils.copy(stream, out);
@@ -216,13 +186,9 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
         if (message.getContent() instanceof Multipart) {
             Multipart mp = (Multipart) message.getContent();
             for (int i = 0; i < mp.getCount(); i++) {
-                try (ByteArrayOutputStream writer = new ByteArrayOutputStream()) {
-                    mp.getBodyPart(i).writeTo(writer);
-                    String partData = writer.toString("UTF-8");
-
-                    if (!mp.getBodyPart(i).getContentType().contains("application/pgp-signature")) {
-                        return asStream(normalize(getMimeSection(partData, getBoundry(message))));
-                    }
+                // Check that the subsequent mime part is the signature
+                if ((i < mp.getCount() - 1) && mp.getBodyPart(i + 1).getContentType().contains("application/pgp-signature")) {
+                    return new SignatureStream(mp.getBodyPart(i));
                 }
             }
         }
@@ -326,12 +292,13 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
 
 
     private List<PGPSignatureVerificationResult> verifyMimeEmailSignature(MimeMessage message, UserIdentity userIdentity) throws OXException {
-        InputStream signedData;
-        InputStream signature;
+        InputStream signedData = null;
+        InputStream signature = null;
         try {
             signedData = requireSignedDataNotNull(extractSignedDataFromMime(message));
             signature = requireSignatureNotNull(extractMimeSignatureFromMime(message));
         } catch (IOException | MessagingException e) {
+            IOUtils.closeQuietly(signedData);  // If signature was null, close signedData
             throw GuardCoreExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
         };
 
@@ -341,6 +308,9 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
         }
         catch(Exception e) {
             return Arrays.asList(new PGPSignatureVerificationResult(e.getMessage()));
+        } finally {
+            IOUtils.closeQuietly(signature);
+            IOUtils.closeQuietly(signedData);
         }
     }
 
@@ -353,6 +323,9 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
         }
         catch(Exception e) {
             return Arrays.asList(new PGPSignatureVerificationResult(e.getMessage()));
+        } finally {
+            IOUtils.closeQuietly(signature);
+            IOUtils.closeQuietly(signedData);
         }
     }
 
