@@ -178,7 +178,7 @@ public class TokenAuthenticationServiceImpl implements TokenAuthenticationServic
                 .setPGPSession(PGPSymmetricKey.fromBase64(json.getString("pgp_session_key")));
         }
 
-        if(json.has("user_id") && json.has("cid")) {
+        if(ret != null && json.has("user_id") && json.has("cid")) {
             final int userId = json.getInt("user_id");
             final int cid = json.getInt("cid");
             ret.setOXGuardUser(new OXGuardUser(userId, cid));
