@@ -53,6 +53,7 @@ import java.io.InputStream;
 import java.io.OutputStream;
 import java.util.List;
 import com.openexchange.exception.OXException;
+import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.user.UserIdentity;
 import com.openexchange.pgp.core.PGPSignatureVerificationResult;
 
@@ -75,6 +76,18 @@ public interface PGPSigningService {
      */
     void sign(InputStream input, OutputStream output, boolean armored, UserIdentity signer) throws OXException;
 
+    /**
+     * Creates a signature
+     *
+     * @param input The data to create a signature for
+     * @param output The signature
+     * @param armored True, if the signature should be written ASCII-Armored, false if binary
+     * @param signerKey The GuardKeys to create the signature with
+     * @param password The password
+     * @throws OXException
+     */
+    void sign(InputStream input, OutputStream output, boolean armored, GuardKeys signerKey, char[] password) throws OXException;
+
     /**
      * Verifies signatures
      *
