@@ -79,7 +79,7 @@ public class GuardStorageActivator extends HousekeepingActivator {
      */
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class<?>[] { GuardShardingService.class, GuardDatabaseService.class };
+        return new Class<?>[] { GuardDatabaseService.class };
     }
 
     /*
