@@ -131,6 +131,9 @@ public class GuardTranslationServiceImpl implements GuardTranslationService {
     private void loadAvailableLanguages() throws OXException {
         GuardConfigurationService configService = Services.getService(GuardConfigurationService.class);
         String l10nDirectory = configService.getProperty("i18n.language.path");
+        if (null == l10nDirectory) {
+            throw OXException.notFound("Configuration property 'i18n.language.path' is not defined.");
+        }
         // Get and set the default code
         defaultCode = configService.getProperty(GuardProperty.defaultLanguage);
         try {
@@ -486,7 +489,9 @@ public class GuardTranslationServiceImpl implements GuardTranslationService {
         return defaultCode;
     }
 
-    /* (non-Javadoc)
+    /*
+     * (non-Javadoc)
+     * 
      * @see com.openexchange.guard.translation.GuardTranslationService#getAvailableLocale(java.lang.String)
      */
     @Override
@@ -518,7 +523,7 @@ public class GuardTranslationServiceImpl implements GuardTranslationService {
                         avail = defaultCode;
                     } else {
                         if (value.containsKey(defaultCode.substring(0, 2))) {
-                            avail = defaultCode.substring(0,2);
+                            avail = defaultCode.substring(0, 2);
                         }
                     }
                 }
