@@ -49,6 +49,7 @@
 
 package com.openexchange.guard.update.internal;
 
+import java.util.Objects;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.openexchange.exception.OXException;
@@ -81,7 +82,7 @@ public class GuardUpdateServiceImpl implements GuardUpdateService {
 
     private boolean checkUpgrade() {
         try {
-            GlobalSettingsStorage globalSettingsStorage = Services.getService(GlobalSettingsStorage.class);
+            GlobalSettingsStorage globalSettingsStorage = Objects.requireNonNull(Services.getService(GlobalSettingsStorage.class), "Missing GlobalSettingsStorage service");
             int previousVersion = Integer.parseInt(globalSettingsStorage.getByKey("version"));
 
             GuardConfigurationService configService = Services.getService(GuardConfigurationService.class);
