@@ -92,7 +92,7 @@ public class MissingPGPPreferences implements KeyUpgradeTask {
     private static int[] PREFERRED_COPMRESSION = new int[] { CompressionAlgorithmTags.ZLIB, CompressionAlgorithmTags.BZIP2, CompressionAlgorithmTags.ZIP, CompressionAlgorithmTags.UNCOMPRESSED };
 
 
-    private KeyTableStorage ogKeyTableStorage;
+    private final KeyTableStorage ogKeyTableStorage;
     private static final Logger LOG = LoggerFactory.getLogger(MissingPGPPreferences.class);
 
     public MissingPGPPreferences (KeyTableStorage ogKeyTableStorage) {
@@ -119,7 +119,10 @@ public class MissingPGPPreferences implements KeyUpgradeTask {
            LOG.info("No private key available for upgrade of public key preferences.  Skipping");
            return;
         }
-      //Getting the private key used for singing
+        if (masterSecretKey.getPublicKey().getAlgorithm() > 3) {  // Only applies to RSA keys.  Return if not RSA
+            return;
+        }
+        //Getting the private key used for signing
         PGPPrivateKey signingPrivateKey = null;
         try {
             signingPrivateKey = PGPUtil.decodePrivate(masterSecretKey, password, key.getSalt());
