@@ -53,6 +53,7 @@ import java.io.IOException;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
+import java.util.Map.Entry;
 import java.util.concurrent.atomic.AtomicReference;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
@@ -219,6 +220,16 @@ public class LoginHandler {
             }
             // Keys found, log the login activity
             logActivity(keys.getUserid(), keys.getContextid());
+
+            // Check language not updated
+            try {
+                if (keys.getLocale() == null || !keys.getLocale().equals(userSession.getLocale())) {
+                    updateLocale(keys, userSession.getLocale());
+                }
+            } catch (IllegalArgumentException e) {
+                LOG.error("Invalid locale {} for user keys: {}", keys.getLanguage(), keys.getEmail());
+            }
+
             returnJson.addProperty("primaryEmail", keys.getEmail());
             returnJson.add("settings", AuthUtils.getSettings(keys.getSettings().toString(), settings, userid, cid));
             returnJson.add("recoveryAvail", new JsonPrimitive(keys.isRecoveryAvail()));
@@ -242,6 +253,7 @@ public class LoginHandler {
                 LOG.debug("Auth sent with Password Needed for cid = " + cid + " userid = " + userid);
                 return;
             }
+
             // OK, let's authenticate
             GuardCipherService cipherService = Services.getService(GuardCipherFactoryService.class).getCipherService(GuardCipherAlgorithm.AES_GCM);
             try {
@@ -261,8 +273,8 @@ public class LoginHandler {
                                         keys.getContextid(),
                                         keys.getEmail(),
                                         ENCR_PASSWORD_AUTH_FIELD_NAME,
-                                        json.has("encr_password") ? json.get("encr_password").getAsString() : "",
-                                        json.has("language") ? json.get("language").getAsString() : "").toString(),
+                                        (json != null && json.has("encr_password")) ? json.get("encr_password").getAsString() : "",
+                                        (json != null && json.has("language")) ? json.get("language").getAsString() : "").toString(),
                                     getToken(userSession));
                             antiabuse.report(AntiAbuseUtils.getReportParameter(true, request, userid,  cid, encrpass));
                             LOG.debug("Auth with proper password for cid = " + cid + " userid = " + userid);
@@ -319,6 +331,18 @@ public class LoginHandler {
         }
     }
 
+    /**
+     * If the key locale is different from the UI login, update the key data
+     * @param key
+     * @param locale
+     * @throws OXException
+     */
+    private void updateLocale(GuardKeys key, Locale locale) throws OXException {
+        key.setLocale(locale);
+        KeyTableStorage keyService = Services.getService(KeyTableStorage.class);
+        keyService.updateLocale(key);
+    }
+
     /**
      * Obtain a session token for this session
      * @param GuardUserSession
@@ -384,7 +408,8 @@ public class LoginHandler {
         }
         Map<String, String> available = translationService.getAvailableLanguages(code);
         JsonObject jsonAvailable = new JsonObject();
-        for (String key : available.keySet()) {
+        for (final java.util.Iterator<Entry<String, String>> it = available.entrySet().iterator(); it.hasNext();) {
+            String key = it.next().getKey();
             jsonAvailable.addProperty(key, available.get(key));
         }
         return jsonAvailable;
