@@ -200,20 +200,29 @@ public class ResetPasswordHandler {
             }
             throw GuardCoreExceptionCodes.DISABLED_ERROR.create("reset password");
         }
-        String newpass = keyService.generatePassword();
+        String newpass = keyService.generatePassword(userIdentity.getOXGuardUser().getId(), userIdentity.getOXGuardUser().getContextId());
 
         MailCreatorService mailCreatorService = Services.getService(MailCreatorService.class);
         GuardNotificationService guardNotificationService = Services.getService(GuardNotificationService.class);
+        int senderId = userIdentity.getOXUser() == null ? -1 : userIdentity.getOXUser().getId();
+        int senderCid = userIdentity.getOXUser() == null ? userIdentity.getOXGuardUser().getContextId() : userIdentity.getOXUser().getContextId();
+        List<String> fromEmail = mailCreatorService.getFromAddress(userEmail,
+            userEmail,
+            senderId,
+            senderCid);
         JsonObject mail = mailCreatorService.getResetEmail(
             secondEmail,
-            mailCreatorService.getFromAddress(userEmail, userEmail, userIdentity.getOXUser().getId(), userIdentity.getOXUser().getContextId()),
+            fromEmail,
             newpass,
             lang,
             templid,
             host,
             userIdentity.getOXGuardUser().getId(),
             userIdentity.getOXGuardUser().getContextId());
-        guardNotificationService.send(mail, senderIp);
+        guardNotificationService.send(mail,
+            senderId,
+            senderCid,
+            senderIp);
 
         keyService.resetPassword(userEmail, newpass);
     }
