@@ -49,6 +49,7 @@
 
 package com.openexchange.guard.osgi;
 
+import java.util.concurrent.TimeUnit;
 import org.osgi.service.http.HttpService;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -57,7 +58,11 @@ import com.openexchange.context.ContextService;
 import com.openexchange.guard.GuardMaintenanceService;
 import com.openexchange.guard.activity.ActivityTrackingService;
 import com.openexchange.guard.antiabuse.GuardAntiAbuseService;
+import com.openexchange.guard.autocrypt.AutoCryptService;
+import com.openexchange.guard.autocrypt.database.AutoCryptStorageService;
+import com.openexchange.guard.cipher.GuardCipherAlgorithm;
 import com.openexchange.guard.cipher.GuardCipherFactoryService;
+import com.openexchange.guard.cipher.GuardCipherService;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProperty;
 import com.openexchange.guard.cron.CleanAuthenticationTokenTask;
@@ -65,6 +70,7 @@ import com.openexchange.guard.cron.CleanRemoteKeyCacheTask;
 import com.openexchange.guard.cron.CleanTemporaryTokensTask;
 import com.openexchange.guard.cron.DailyTaskScheduler;
 import com.openexchange.guard.cron.GuestCleanupTask;
+import com.openexchange.guard.cron.PopulateKeyCacheTask;
 import com.openexchange.guard.cron.ResetExposedKeysTask;
 import com.openexchange.guard.database.GuardDatabaseService;
 import com.openexchange.guard.database.GuardShardingService;
@@ -101,13 +107,13 @@ import com.openexchange.guard.keymanagement.storage.KeyTableStorage;
 import com.openexchange.guard.keymanagement.storage.OGPGPKeysStorage;
 import com.openexchange.guard.keymanagement.storage.PGPKeysStorage;
 import com.openexchange.guard.keymanagement.storage.RemoteKeyCacheStorage;
-import com.openexchange.guard.keys.PGPKeyService;
 import com.openexchange.guard.mailcreator.MailCreatorService;
 import com.openexchange.guard.mime.services.MimeEncryptionService;
 import com.openexchange.guard.notification.GuardNotificationService;
 import com.openexchange.guard.oxapi.pooling.HttpConnectionPoolService;
 import com.openexchange.guard.pgpcore.services.PGPCryptoService;
 import com.openexchange.guard.pgpcore.services.PGPKeySigningService;
+import com.openexchange.guard.pgpcore.services.PGPMimeSigningService;
 import com.openexchange.guard.pgpcore.services.PGPPacketService;
 import com.openexchange.guard.pgpcore.services.PGPSigningService;
 import com.openexchange.guard.pgpcore.services.TokenAuthenticationService;
@@ -126,6 +132,7 @@ import com.openexchange.guard.user.OXUserService;
 import com.openexchange.osgi.HousekeepingActivator;
 import com.openexchange.pgp.keys.parsing.PGPKeyRingParser;
 import com.openexchange.startup.SignalHttpApiAvailabilityService;
+import com.openexchange.timer.ScheduledTimerTask;
 import com.openexchange.timer.TimerService;
 
 /**
@@ -138,6 +145,7 @@ public class GuardServiceActivator extends HousekeepingActivator {
 
     private static final Logger LOG = LoggerFactory.getLogger(GuardServiceActivator.class);
     private DailyTaskScheduler dailyJobScheduler;
+    private ScheduledTimerTask scheduledKeyCacheTask;
 
     /*
      * (non-Javadoc)
@@ -149,16 +157,17 @@ public class GuardServiceActivator extends HousekeepingActivator {
         return new Class<?>[] { HttpService.class, SignalHttpApiAvailabilityService.class,
             GuardConfigurationService.class, GuardMasterKeyService.class, TimerService.class, GuardTranslationService.class,
             GuardRatifierService.class, GuardCipherFactoryService.class, GuardDatabaseService.class, GuardSessionService.class,
-            KeyCacheStorage.class, RecipKeyService.class, MailCreatorService.class, DNSService.class, PGPKeyService.class, GlobalSettingsStorage.class,
+            KeyCacheStorage.class, RecipKeyService.class, MailCreatorService.class, DNSService.class, GlobalSettingsStorage.class,
             GuardNotificationService.class, GuardAntiAbuseService.class, GuardKeyService.class, EmailStorage.class,
             GuardShardingService.class, KeyTableStorage.class, PGPKeysStorage.class, EncryptedItemsStorage.class, OGPGPKeysStorage.class,
             DeletedKeysStorage.class, Storage.class, GuardUpdateService.class, GuestUpgradeService.class, HKPClientService.class,
-            PGPCryptoService.class, PGPSigningService.class, TokenAuthenticationService.class, FileCacheStorage.class, RemoteKeyCacheStorage.class,
+            PGPCryptoService.class, PGPSigningService.class, PGPMimeSigningService.class, TokenAuthenticationService.class, FileCacheStorage.class, RemoteKeyCacheStorage.class,
             GuestResetService.class, TemporaryTokenService.class, KeyCreationService.class, OXUserService.class, KeyRecoveryService.class,
             PasswordChangeService.class, AccountCreationService.class, PublicExternalKeyService.class, KeyImportService.class, ContextService.class,
             MimeEncryptionService.class, PGPKeyRingParser.class, ImportSystemPublicKey.class, PGPPacketService.class, GuardGuestService.class,
             PGPKeySigningService.class, ContactKeyService.class, SharingService.class, GuardGuestEMailMetadataService.class,
-            GuestConverterService.class, GuestRedirectorService.class, GuestLookupService.class, SecondFactorService.class, GuardKeysUpdater.class };
+            GuestConverterService.class, GuestRedirectorService.class, GuestLookupService.class, SecondFactorService.class, GuardKeysUpdater.class,
+            AutoCryptService.class, AutoCryptStorageService.class};
     }
 
     @Override
@@ -185,7 +194,6 @@ public class GuardServiceActivator extends HousekeepingActivator {
         trackService(GuardMaintenanceService.class);
 
         trackService(HttpConnectionPoolService.class);
-
         registerService(ResponseHandler.class, new ResponseHandlerImpl(getService(GuardMasterKeyService.class), getService(GuardCipherFactoryService.class)));
         trackService(ResponseHandler.class);
 
@@ -193,8 +201,23 @@ public class GuardServiceActivator extends HousekeepingActivator {
 
         Services.getService(GuardUpdateService.class).createMasterKeysIfNecessary();
 
-        // Initializing daily cron jobs
         GuardConfigurationService guardConfigurationService = getService(GuardConfigurationService.class);
+
+
+        //Intialize key cache task
+        if (guardConfigurationService.getBooleanProperty(GuardProperty.rsaCache)) {
+            GuardCipherService AES_CBC = Services.getService(GuardCipherFactoryService.class).getCipherService(GuardCipherAlgorithm.AES_CBC);
+            PopulateKeyCacheTask populateKeyCacheTask = new PopulateKeyCacheTask(guardConfigurationService,
+                    getService(KeyCacheStorage.class),
+                    AES_CBC,
+                    getService(GuardMasterKeyService.class));
+            TimerService timerService = getService(TimerService.class);
+            this.scheduledKeyCacheTask = timerService.scheduleAtFixedRate(populateKeyCacheTask,
+                    0,
+                    guardConfigurationService.getIntProperty(GuardProperty.keyCacheCheckInterval),
+                    TimeUnit.SECONDS);
+        }
+        // Initializing daily cron jobs
         dailyJobScheduler = new DailyTaskScheduler(guardConfigurationService.getIntProperty(GuardProperty.cronHour));
         dailyJobScheduler.register(new CleanRemoteKeyCacheTask(guardConfigurationService.getIntProperty(GuardProperty.pgpCacheDays)));
         dailyJobScheduler.register(new CleanAuthenticationTokenTask(ConfigTools.parseTimespan(guardConfigurationService.getProperty(GuardProperty.authLifeTime))));
@@ -226,6 +249,9 @@ public class GuardServiceActivator extends HousekeepingActivator {
         if (poolService != null) {
             poolService.closeAll();
         }
+        if(scheduledKeyCacheTask != null) {
+            scheduledKeyCacheTask.cancel();
+        }
         if (dailyJobScheduler != null) {
             dailyJobScheduler.unregisterAll();
         }
