@@ -55,6 +55,7 @@ import java.util.List;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import org.json.JSONObject;
+import org.slf4j.event.Level;
 import com.openexchange.antiabuse.AllowParameters;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.antiabuse.GuardAntiAbuseService;
@@ -71,6 +72,7 @@ import com.openexchange.guard.keymanagement.commons.antiabuse.KeyAntiAbuseWrappe
 import com.openexchange.guard.keymanagement.commons.antiabuse.UserAntiAbuseWrapper;
 import com.openexchange.guard.keymanagement.services.GuardMasterKeyService;
 import com.openexchange.guard.logging.GuardLogProperties;
+import com.openexchange.guard.logging.LoggingHelper;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.pgpcore.services.TokenAuthenticationService;
 import com.openexchange.guard.servlets.authentication.AuthenticationDataExtractor;
@@ -80,7 +82,10 @@ import com.openexchange.guard.servlets.authentication.GuestSessionValidator;
 import com.openexchange.guard.servlets.authentication.RestSessionValidator;
 import com.openexchange.guard.servlets.authentication.UserIdentityJsonParser;
 import com.openexchange.guard.servlets.authentication.UserIdentityParameterParser;
+import com.openexchange.guard.translation.GuardTranslationService;
+import com.openexchange.guard.translation.GuardTranslator;
 import com.openexchange.guard.user.UserIdentity;
+import com.openexchange.i18n.Translator;
 
 /**
  * Represents an OX Guard HTTP action
@@ -125,6 +130,15 @@ public abstract class GuardServletAction {
         return userIdentity;
     }
 
+    /**
+     * Gets the {@link org.slf4j.event.Level} to use for logging the execution of the {@link GuardServletAction}
+     *
+     * @return The {@link org.slf4j.event.Level} to use
+     */
+    protected Level getLogLevel() {
+        return Level.INFO;
+    }
+
     /**
      * Fluent like method to set the authentication handlers
      *
@@ -234,7 +248,7 @@ public abstract class GuardServletAction {
         GuardLogProperties.put(GuardLogProperties.Name.GUEST_USER_ID, userSession.getUserId());
         GuardLogProperties.put(GuardLogProperties.Name.GUEST_SESSION_ID, userSession.getSessionId());
 
-        LOG.info(String.format("Command sent \"%s\" from IP %s", ServletUtils.getStringParameter(request, "action"), ServletUtils.getClientIP(request)));
+        LoggingHelper.Log(LOG, getLogLevel(), String.format("Command sent \"%s\" from IP %s", ServletUtils.getStringParameter(request, "action"), ServletUtils.getClientIP(request)));
     }
 
     /**
@@ -251,7 +265,7 @@ public abstract class GuardServletAction {
             GuardLogProperties.put(GuardLogProperties.Name.SESSION_SESSION_ID, userSession.getSessionId());
         }
 
-        LOG.info(String.format("Command sent \"%s\" from IP %s", ServletUtils.getStringParameter(request, "action"), ServletUtils.getClientIP(request)));
+        LoggingHelper.Log(LOG, getLogLevel(), String.format("Command sent \"%s\" from IP %s", ServletUtils.getStringParameter(request, "action"), ServletUtils.getClientIP(request)));
     }
 
     /**
@@ -342,6 +356,8 @@ public abstract class GuardServletAction {
         return requireOrReturn(userIdentity, require);
     }
 
+
+
     /**
      * Parses a {@link UserIdentity} from the given {@link JSONObject}
      *
@@ -366,6 +382,33 @@ public abstract class GuardServletAction {
         return requireOrReturn(userIdentity, require);
     }
 
+    /**
+     * Parses a {@link UserIdentity} from the given {@link GuardUserSession} and the provided authentication token
+     *
+     * @param guardSession The user session to use
+     * @param authToken The auth token to use
+     * @return The parsed {@link UserIdentity}, or null if the request did not contain enough information for creating a {@link UserIdentity} object.
+     * @throws OXException
+     */
+    protected UserIdentity getUserIdentityFrom(GuardUserSession guardSession, String authToken) throws OXException {
+        TokenAuthenticationService service = Services.getService(TokenAuthenticationService.class);
+        return service.decryptUserIdentity(guardSession.getGuardSession(), authToken);
+    }
+
+    /**
+     * Parses a {@link UserIdentity} from the given {@link GuardUserSession} and the provided authentication token, or throws an Exception if the request does not contain enough information for creating a {@link UserIdentity} object.
+     *
+     * @param guardSession The user session to use
+     * @param authToken The auth token to use
+     * @return The parsed {@link UserIdentity}, or null if the request did not contain enough information for creating a {@link UserIdentity} object.
+     * @throws OXException
+     */
+    protected UserIdentity requireUserIdentityFrom(GuardUserSession guardSession, String authToken) throws OXException {
+        final UserIdentity userIdentity = getUserIdentityFrom(guardSession, authToken);
+        final boolean require = true;
+        return requireOrReturn(userIdentity, require);
+    }
+
     /**
      * Gets a {@link UserIdentity} from the given {@link GuardUserSession}
      *
@@ -377,6 +420,17 @@ public abstract class GuardServletAction {
         return AuthUtils.getUserIdentityFrom(guardUserSession);
     }
 
+    /**
+     * Gets a {@link Translator} for the given session's locale
+     *
+     * @param guardUserSession The session containing the locale
+     * @return The translator for the given sesison's locale, or the default translator
+     * @throws OXException
+     */
+    protected GuardTranslator getTranslatorFrom(GuardUserSession guardUserSession) throws OXException {
+       return new GuardTranslator(Services.getService(GuardTranslationService.class), guardUserSession.getLocale());
+    }
+
     /**
      * Template method which allows implementation of the action execution by subclasses
      *
