@@ -67,7 +67,6 @@ import com.openexchange.guard.servlets.keymanagement.KeymanagementServlet;
 import com.openexchange.guard.servlets.keyretrieval.KeyRetrievalServlet;
 import com.openexchange.guard.servlets.login.LoginServlet;
 import com.openexchange.guard.servlets.mail.MailServlet;
-import com.openexchange.guard.servlets.pgp.PGPServlet;
 import com.openexchange.guard.servlets.pgpcore.PGPCoreServlet;
 import com.openexchange.guard.servlets.pgpmail.PGPMailServlet;
 import com.openexchange.guard.servlets.ping.PingServlet;
@@ -87,7 +86,6 @@ public class GuardServlets {
     private static final String GUARD_PING_SERVLET_PATH = "/oxguard/ping";
     private static final String GUARD_KEY_MANAGEMENT_SERVLET_PATH = "/oxguard/keys";
     private static final String GUARD_PGP_CORE_SERVLET_PATH = "/oxguard/pgpcore";
-    private static final String GUARD_PGP_SERVLET_PATH = "/oxguard/pgp";
     private static final String GUARD_PGPMAIL_SERVLET_PATH = "/oxguard/pgpmail";;
     private static final String GUARD_MAIL_SERVLET_PATH = "/oxguard/mail";;
     private static final String GUARD_GUEST_SERVLET_PATH = "/oxguard/guest";
@@ -123,7 +121,6 @@ public class GuardServlets {
         httpService.registerServlet(GUARD_PING_SERVLET_PATH, new PingServlet(), null, null);
         httpService.registerServlet(GUARD_KEY_MANAGEMENT_SERVLET_PATH, new KeymanagementServlet(), null, null);
         httpService.registerServlet(GUARD_PGP_CORE_SERVLET_PATH, new PGPCoreServlet(), null, null);
-        httpService.registerServlet(GUARD_PGP_SERVLET_PATH, new PGPServlet(), null, null);
         httpService.registerServlet(GUARD_PGPMAIL_SERVLET_PATH, new PGPMailServlet(), null, null);
         httpService.registerServlet(GUARD_MAIL_SERVLET_PATH, new MailServlet(), null, null);
         httpService.registerServlet(GUARD_LOGIN_SERVLET_PATH, new LoginServlet(basicRestAuthServletAuthentication), null, null);
@@ -147,7 +144,6 @@ public class GuardServlets {
         }
         httpService.unregister(GUARD_PING_SERVLET_PATH);
         httpService.unregister(GUARD_PGP_CORE_SERVLET_PATH);
-        httpService.unregister(GUARD_PGP_SERVLET_PATH);
         httpService.unregister(GUARD_PGPMAIL_SERVLET_PATH);
         httpService.unregister(GUARD_MAIL_SERVLET_PATH);
         httpService.unregister(GUARD_LOGIN_SERVLET_PATH);
