@@ -85,7 +85,7 @@ public class CheckGuestAction extends GuardServletAction {
                 found = true;
             } else {
                 FileCacheStorage fs = Services.getService(FileCacheStorage.class);
-                List<FileCacheItem> items = fs.getForUser(guest.getUserId(), 0, 2);  // Check if any items exist
+                List<FileCacheItem> items = fs.getForUser(guest.getUserId(), guest.getContextId(), 0, 2);  // Check if any items exist
                 if (!items.isEmpty()) found = true;
             }
         }
