@@ -52,16 +52,22 @@ package com.openexchange.guard.servlets.fileupload;
 import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
+import java.security.NoSuchAlgorithmException;
 import java.util.Collection;
 import java.util.Objects;
+import javax.mail.util.SharedFileInputStream;
 import javax.servlet.http.HttpServletRequest;
 import org.apache.commons.fileupload.FileItem;
+import org.apache.commons.fileupload.FileItemFactory;
 import org.apache.commons.fileupload.FileItemIterator;
 import org.apache.commons.fileupload.FileUploadException;
+import org.apache.commons.fileupload.disk.DiskFileItem;
 import org.apache.commons.fileupload.disk.DiskFileItemFactory;
+import org.apache.commons.fileupload.servlet.FileCleanerCleanup;
 import org.apache.commons.fileupload.servlet.ServletFileUpload;
 import org.apache.commons.io.output.DeferredFileOutputStream;
 import com.openexchange.exception.OXException;
+import com.openexchange.guard.cipher.GuardCipherAlgorithm;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProperty;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
@@ -79,7 +85,10 @@ public class FileUploadHandler {
 
     private static final String GUARD_FILE_SUFFIX = ".grd";
     private static final String GUARD_FILE_PREFIX = "guard-";
+    private static final GuardCipherAlgorithm ENCRYPTION_ALGORITHM = GuardCipherAlgorithm.AES_CBC;
+
     private final GuardConfigurationService configurationService;
+    private final boolean encrypted;
 
     /**
      * Initializes a new {@link FileUploadHandler}.
@@ -88,6 +97,18 @@ public class FileUploadHandler {
      */
     public FileUploadHandler(GuardConfigurationService configurationService) {
         this.configurationService = Objects.requireNonNull(configurationService, "configurationService must not be null");
+        this.encrypted = false;
+    }
+
+    /**
+     * Initializes a new {@link FileUploadHandler}.
+     *
+     * @param configurationService The configuration to use
+     * @param encrypted True, in order to handle file uploads encrypted when buffered to disk, false to buffer as plain text
+     */
+    public FileUploadHandler(GuardConfigurationService configurationService, boolean encrypted) {
+        this.configurationService = Objects.requireNonNull(configurationService, "configurationService must not be null");
+        this.encrypted = encrypted;
     }
 
     /**
@@ -118,7 +139,9 @@ public class FileUploadHandler {
         long maxSize = -1L;
         if (maxSizeProperty != null) {
             maxSize = Long.parseLong(maxSizeProperty);
-            if (maxSize == 0) maxSize = -1;
+            if (maxSize == 0) {
+                maxSize = -1;
+            }
         }
         return maxSize;
     }
@@ -126,11 +149,23 @@ public class FileUploadHandler {
     /**
      * Creates the {@link ServletFileUpload}.
      *
-     * @para maxUploadSize The max. allowed upload size
+     * @param request The request to create the {@link ServletFileUpload} for
+     * @param maxUploadSize The max. allowed upload size
      * @return The configured, ready to use {@link ServletFileUpload}.
+     * @throws OXException
      */
-    private ServletFileUpload createFileUpload(long maxUploadSize) {
-        ServletFileUpload fileUpload = new ServletFileUpload(new DiskFileItemFactory(getThreshold(), getUploadDirectory()));
+    private ServletFileUpload createFileUpload(HttpServletRequest request, long maxUploadSize) throws OXException {
+        DiskFileItemFactory diskFileItemFactory = new DiskFileItemFactory(getThreshold(), getUploadDirectory());
+        diskFileItemFactory.setFileCleaningTracker(FileCleanerCleanup.getFileCleaningTracker(request.getServletContext()));
+        FileItemFactory fileItemFactory = diskFileItemFactory;
+        if (encrypted) {
+            try {
+                fileItemFactory = new EncryptedFileItemFactory(fileItemFactory, ENCRYPTION_ALGORITHM);
+            } catch (NoSuchAlgorithmException e) {
+                throw GuardCoreExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
+            }
+        }
+        ServletFileUpload fileUpload = new ServletFileUpload(fileItemFactory);
         fileUpload.setFileSizeMax(maxUploadSize);
         fileUpload.setSizeMax(maxUploadSize);
         return fileUpload;
@@ -154,7 +189,7 @@ public class FileUploadHandler {
      */
     public Collection<FileItem> parseItems(HttpServletRequest request) throws OXException {
         try {
-            return createFileUpload(getConfiguredMaxUploadSize()).parseRequest(request);
+            return createFileUpload(request, getConfiguredMaxUploadSize()).parseRequest(request);
         } catch (FileUploadException e) {
             throw GuardCoreExceptionCodes.MULTIPART_UPLOAD_ERROR.create(e, e.getMessage());
         }
@@ -170,7 +205,7 @@ public class FileUploadHandler {
      */
     public Collection<FileItem> parseItems(HttpServletRequest request,long maxUploadSize) throws OXException {
         try {
-            return createFileUpload(maxUploadSize).parseRequest(request);
+            return createFileUpload(request, maxUploadSize).parseRequest(request);
         } catch (FileUploadException e) {
             throw GuardCoreExceptionCodes.MULTIPART_UPLOAD_ERROR.create(e, e.getMessage());
         }
@@ -186,7 +221,7 @@ public class FileUploadHandler {
      */
     public FileItemIterator parseIterator(HttpServletRequest request) throws OXException {
         try {
-            return createFileUpload(getConfiguredMaxUploadSize()).getItemIterator(request);
+            return createFileUpload(request, getConfiguredMaxUploadSize()).getItemIterator(request);
         } catch (FileUploadException e) {
             throw GuardCoreExceptionCodes.MULTIPART_UPLOAD_ERROR.create(e, e.getMessage());
         } catch (IOException e) {
@@ -209,6 +244,17 @@ public class FileUploadHandler {
         try {
             for (FileItem fileItem : fileItems) {
                 if (fileItem.getFieldName().equals(name)) {
+                    if(!fileItem.isInMemory()) {
+                       File tmpFile = null;
+                       if(fileItem instanceof DiskFileItem) {
+                           tmpFile = ((DiskFileItem)fileItem).getStoreLocation();
+                           return new SharedFileInputStream(tmpFile);
+                       }
+                       else if(fileItem instanceof EncryptedFileItem) {
+                           EncryptedFileItem encryptedFileItem = (EncryptedFileItem)fileItem;
+                           return encryptedFileItem.getSharedInputStream();
+                       }
+                    }
                     return fileItem.getInputStream();
                 }
             }
