@@ -1,5 +1,6 @@
 package com.openexchange.guard.servlets.guest;
 
+import java.util.Objects;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import com.google.gson.JsonObject;
@@ -14,7 +15,7 @@ public class DoResetGuardAccount extends GuardServletAction {
 
     @Override
     protected void doActionInternal(HttpServletRequest request, HttpServletResponse response, GuardUserSession userSession) throws Exception {
-        JsonObject data = Services.getService(ResponseHandler.class).getJson(request);
+        JsonObject data = Objects.requireNonNull(Services.getService(ResponseHandler.class).getJson(request), "No JSON in request");
         GuestResetService resetService = Services.getService(GuestResetService.class);
         resetService.doReset(data, ServletUtils.getClientIP(request));
         JsonObject resp = new JsonObject();
