@@ -197,13 +197,13 @@ public class Guest {
             throw GuardCoreExceptionCodes.DISABLED_ERROR.create("reset password");
         }
 
-        String newpass = keyService.generatePassword();
+        String newpass = keyService.generatePassword(userid, cid);
 
         MailCreatorService mailCreatorService = Services.getService(MailCreatorService.class);
         JsonObject mail = mailCreatorService.getResetEmail(email, mailCreatorService.getFromAddress(email, email, userid, cid), newpass, lang, templId, host, userid, cid);
 
         GuardNotificationService guardNotificationService = Services.getService(GuardNotificationService.class);
-        guardNotificationService.send(mail, senderIp);
+        guardNotificationService.send(mail, -1, cid, senderIp);
 
         keyService.resetPassword(email, newpass);
     }
