@@ -87,8 +87,8 @@ public class GuestServlet extends AbstractGuardServlet {
     private static final String APPEND_MESSAGE = "appendmessage";
     private static final String UPGRADE_GUEST = "convertGuest";
 
-    private final HashMap<String, GuardServletAction> getActions;
-    private final HashMap<String, GuardServletAction> postActions;
+    private transient final HashMap<String, GuardServletAction> getActions;
+    private transient final HashMap<String, GuardServletAction> postActions;
 
     /**
      * Initializes a new {@link GuestServlet}.
