@@ -62,6 +62,9 @@ import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.servlets.GuardServletAction;
 import com.openexchange.guard.servlets.authentication.GuardUserSession;
+import com.openexchange.guard.user.GuardCapabilities;
+import com.openexchange.guard.user.OXUserService;
+import com.openexchange.guard.user.UserIdentity;
 
 /**
  * {@link DeleteKeyPairAction}
@@ -79,25 +82,30 @@ public class DeleteKeyPairAction extends GuardServletAction {
 
         final Long keyId = ServletUtils.getLongParameter(request, Parameters.PARAM_KEYID,true);
         final GuardKeyService guardKeyService = Services.getService(GuardKeyService.class);
-        final GuardKeys keyToDelete = guardKeyService.getKeys(userSession.getUserId(), userSession.getContextId(), keyId);
+        final GuardKeys keyToDelete = guardKeyService.getKeys(userSession.getGuardUserId(), userSession.getGuardContextId(), keyId);
 
         if(keyToDelete != null) {
             if(keyToDelete.hasPrivateKey()) {
                 //Brute Force protect the key deletion if the key ring has a password protected private key.
-                final String password = ServletUtils.getStringParameter(request, Parameters.PARAM_PASSWORD, true);
-                AntiAbuseWrapper bruteForceProtection = getAntiAbuseWrapper(keyToDelete, AntiAbuseUtils.getAllowParameters(request, userSession.getUserId(),  userSession.getContextId(), password));
+                final UserIdentity userIdentity = requireUserIdentityFrom(request);
+                GuardCapabilities  settings = Services.getService(OXUserService.class).getGuardCapabilieties(userSession.getContextId(), userSession.getUserId());
+                if (settings.isNoDeletePrivate()) {
+                    throw GuardCoreExceptionCodes.DISABLED_ERROR.create("Delete Private Key");
+                }
+                AntiAbuseWrapper bruteForceProtection = getAntiAbuseWrapper(keyToDelete, AntiAbuseUtils.getAllowParameters(request, userSession.getGuardUserId(),  userSession.getGuardContextId(), new String(userIdentity.getPassword())));
                 bruteForceProtection.doAction(new AntiAbuseAction<Void>() {
 
                     @Override
                     public Void doAction() throws OXException {
-                        guardKeyService.delete(keyToDelete, password);
+                        guardKeyService.delete(keyToDelete, new String(userIdentity.getPassword()), userSession.getUserId(), userSession.getContextId());
                         return null;
                     }});
             }
             else {
                 //Just delete if it is a public only key
-                guardKeyService.delete(keyToDelete, null);
+                guardKeyService.delete(keyToDelete, null, userSession.getUserId(), userSession.getContextId());
             }
+            ServletUtils.sendJsonOK(response, null);
         }
         else {
             throw GuardCoreExceptionCodes.KEY_NOT_FOUND.create();
