@@ -106,7 +106,7 @@ public class GetSignaturesAction extends GuardServletAction {
                     final GuardKeyService keyService = Services.getService(GuardKeyService.class);
                     final PGPKeySigningService pgpKeySigningService = Services.getService(PGPKeySigningService.class);
 
-                    final GuardKeys key = keyService.getKeysBySubKeyId(verifier.getOXGuardUser().getId(), verifier.getOXGuardUser().getContextId(), keyId);
+                    final GuardKeys key = keyService.getKeys(keyId);
                     if (key != null) {
                         if (verifySubkeys) {
                             verificationResults = pgpKeySigningService.verifyKey(verifier, key);
