@@ -56,13 +56,16 @@ import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import org.apache.commons.fileupload.FileItem;
 import org.bouncycastle.openpgp.PGPPublicKeyRing;
+import com.openexchange.guard.common.servlets.utils.ServletUtils;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
+import com.openexchange.guard.keymanagement.commons.OGPGPKeyRing;
 import com.openexchange.guard.keymanagement.services.PublicExternalKeyService;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.servlets.GuardServletAction;
 import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.guard.servlets.fileupload.FileUploadHandler;
+import com.openexchange.guard.servlets.keymanagement.responses.ExternalPublicKeyRingCollectionResponse;
 import com.openexchange.pgp.keys.parsing.KeyRingParserResult;
 import com.openexchange.pgp.keys.parsing.PGPKeyRingParser;
 
@@ -98,8 +101,9 @@ public class UploadExternalPublicKeyAction extends GuardServletAction {
 
         //Adding all parsed key rings
         PublicExternalKeyService publicExternalKeyService = Services.getService(PublicExternalKeyService.class);
-        publicExternalKeyService.importPublicKeyRing(userSession.getUserId(),
-                                                     userSession.getContextId(),
-                                                     parsedPublicKeyRings.toArray(new PGPPublicKeyRing[parsedPublicKeyRings.size()]));
+        List<OGPGPKeyRing> imported = publicExternalKeyService.importPublicKeyRing(userSession.getUserId(),
+                                                                                   userSession.getContextId(),
+                                                                                   parsedPublicKeyRings.toArray(new PGPPublicKeyRing[parsedPublicKeyRings.size()]));
+        ServletUtils.sendObject(response, new ExternalPublicKeyRingCollectionResponse(imported));
     }
 }
