@@ -63,14 +63,13 @@ import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.servlets.utils.AntiAbuseUtils;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
 import com.openexchange.guard.configuration.GuardConfigurationService;
+import com.openexchange.guard.exceptions.GuardAuthExceptionCodes;
 import com.openexchange.guard.inputvalidation.RangeInputValidator;
 import com.openexchange.guard.keymanagement.commons.antiabuse.AntiAbuseAction;
 import com.openexchange.guard.keymanagement.commons.antiabuse.AntiAbuseWrapper;
 import com.openexchange.guard.mime.services.GuardParsedMimeMessage;
 import com.openexchange.guard.mime.services.MimeEncryptionService;
 import com.openexchange.guard.osgi.Services;
-import com.openexchange.guard.pgp.exceptions.GuardPGPExceptionCodes;
-import com.openexchange.guard.pgpcore.services.TokenAuthenticationService;
 import com.openexchange.guard.servlets.GuardServletAction;
 import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.guard.servlets.fileupload.FileUploadHandler;
@@ -88,18 +87,6 @@ public class DecryptMimeEmailAction extends GuardServletAction  {
     private static final String JSON_AUTH_FIELD_NAME = "guardAuth";
     private static final String MESSAGE_FIELD_NAME = "file";
 
-    /**
-     * Constructs an UserIdentity from a given authToken
-     *
-     * @param sessionIdentifier The client identifier
-     * @param authToken The authToken
-     * @return The decrypted UserIdentifier
-     * @throws OXException
-     */
-    private UserIdentity getIdentityForToken(String sessionIdentifier, String authToken) throws OXException {
-        TokenAuthenticationService service = Services.getService(TokenAuthenticationService.class);
-        return service.decryptUserIdentity(sessionIdentifier, authToken);
-    }
 
     private GuardParsedMimeMessage parseMimeMessage(HttpServletRequest request, JSONObject json, InputStream messageStream, int userId, int contextId) throws MessagingException, JSONException, OXException, FileUploadException, IOException {
         return ParseIncoming.parse(request, json, messageStream, userId, contextId, null, null, false);
@@ -128,7 +115,7 @@ public class DecryptMimeEmailAction extends GuardServletAction  {
             //Extracting user identity from the authenticationToken
             UserIdentity userIdentity = getUserIdentityFrom(guardAuth);
             if (userIdentity == null) {
-                throw GuardPGPExceptionCodes.BAD_PASSWORD_ERROR.create();
+                throw GuardAuthExceptionCodes.BAD_PASSWORD.create();
             }
 
             //This abuse wrapper does protect from wrong passwords inside of a valid auth-Token. Not from non-valid auth-tokens.
