@@ -51,11 +51,9 @@ package com.openexchange.guard.servlets.pgpmail;
 
 import java.io.IOException;
 import java.io.InputStream;
-import java.nio.charset.StandardCharsets;
 import java.util.Objects;
 import javax.mail.MessagingException;
 import javax.servlet.http.HttpServletRequest;
-import org.apache.commons.io.IOUtils;
 import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.exception.OXException;
@@ -80,9 +78,7 @@ public class ParseIncoming {
         if (request.getHeader("X-Host-Name") != null) {
             host = request.getHeader("X-Host-Name");
         }
-
-        String messageString = message != null ? new String(IOUtils.toByteArray(message),StandardCharsets.UTF_8) : "";
-    	GuardParsedMimeMessage msg = new GuardParsedMimeMessage(messageString, json, userId, contextId, fromName, draft, host, senderEmail, senderIsGuest);
+    	GuardParsedMimeMessage msg = new GuardParsedMimeMessage(message, json, userId, contextId, fromName, draft, host, senderEmail, senderIsGuest);
     	return msg;
     }
 }
