@@ -52,6 +52,7 @@ package com.openexchange.guard.servlets.pgpmail;
 import java.io.IOException;
 import java.io.InputStream;
 import java.util.Collection;
+import java.util.List;
 import javax.mail.MessagingException;
 import javax.mail.internet.MimeMessage;
 import javax.servlet.http.HttpServletRequest;
@@ -60,16 +61,20 @@ import org.apache.commons.fileupload.FileItem;
 import org.apache.commons.fileupload.FileUploadException;
 import org.json.JSONException;
 import com.openexchange.exception.OXException;
+import com.openexchange.guard.auth.AuthUtils;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
+import com.openexchange.guard.common.util.GuardMimeHeaders;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.inputvalidation.RangeInputValidator;
 import com.openexchange.guard.mime.services.GuardParsedMimeMessage;
 import com.openexchange.guard.osgi.Services;
-import com.openexchange.guard.pgp.signing.GuardEmailSigningService;
-import com.openexchange.guard.pgp.signing.impl.GuardEmailSigningServiceImpl;
+import com.openexchange.guard.pgpcore.services.PGPMimeSigningService;
+import com.openexchange.guard.pgpcore.services.PGPSignatureVerificationResultUtil;
 import com.openexchange.guard.servlets.GuardServletAction;
 import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.guard.servlets.fileupload.FileUploadHandler;
+import com.openexchange.guard.user.UserIdentity;
+import com.openexchange.pgp.core.PGPSignatureVerificationResult;
 
 /**
  * {@link VerifyMimeEmailAction}
@@ -100,9 +105,21 @@ public class VerifyMimeEmailAction extends GuardServletAction  {
         Collection<FileItem> items = fileUploadHandler.parseItems(request);
         try(InputStream messageStream = fileUploadHandler.getFileItemStreamFrom(items, MESSAGE_FIELD_NAME, true);){
             final GuardParsedMimeMessage parsedMimeMessage = parseMimeMessage(request, messageStream, userId, contextId);
-            GuardEmailSigningService signing = new GuardEmailSigningServiceImpl();
-            MimeMessage result = signing.verifyEmailSignature(parsedMimeMessage.getMessage(), userId, contextId);
-            result.writeTo(response.getOutputStream());
+            UserIdentity userIdentity = AuthUtils.getUserIdentityFrom(userId, contextId);
+
+            final MimeMessage messageToVerify = parsedMimeMessage.getMessage();
+
+            //new:
+            messageToVerify.removeHeader(GuardMimeHeaders.X_GUARD_SIGNATURE_RESULT);
+            PGPMimeSigningService pgpMimeSigningService = Services.getService(PGPMimeSigningService.class);
+            List<PGPSignatureVerificationResult> verificationResults = pgpMimeSigningService.verify(messageToVerify, userIdentity);
+            if(verificationResults != null) {
+                String[] headers = PGPSignatureVerificationResultUtil.toHeaders(verificationResults);
+                for(String header : headers) {
+                    messageToVerify.addHeader(GuardMimeHeaders.X_GUARD_SIGNATURE_RESULT, header);
+                }
+            }
+            messageToVerify.writeTo(response.getOutputStream());
         }
     }
 
